;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;-*-mode:scheme-*-
;;;                                                                       ;;
;;;                            [SOMEBODY]                                 ;;
;;;                         Copyright (c) 2000                            ;;
;;;                        All Rights Reserved.                           ;;
;;;                                                                       ;;
;;;  Distribution policy                                                  ;;
;;;     [CHOOSE ONE OF]                                                   ;;
;;;     Free for any use                                                  ;;
;;;     Free for non commercial use                                       ;;
;;;     something else                                                    ;;
;;;                                                                       ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;;  An example diphone voice
;;;
;;;  Authors: [The people who did the work]
;;;

;;; Try to find out where we are
(if (assoc 'crblp_bnBD_alg_diphone voice-locations)
    (defvar crblp_bnBD_alg_dir 
      (cdr (assoc 'crblp_bnBD_alg_diphone voice-locations)))
    ;;; Not installed in Festival yet so assume running in place
    (defvar crblp_bnBD_alg_dir (pwd)))

(if (not (probe_file (path-append crblp_bnBD_alg_dir "festvox/")))
    (begin
     (format stderr "crblp_bnBD_alg: Can't find voice scm files they are not in\n")
     (format stderr "   %s\n" (path-append crblp_bnBD_alg_dir "festvox/"))
     (format stderr "   Either the voice isn't linked into Festival\n")
     (format stderr "   or you are starting festival in the wrong directory\n")
     (error)))

;;;  Add the directory contains general voice stuff to load-path
(set! load-path (cons (path-append crblp_bnBD_alg_dir "festvox/") load-path))

;;; Voice specific parameter are defined in each of the following
;;; files
(require 'crblp_bnBD_alg_phoneset)
(require 'crblp_bnBD_alg_tokenizer)
(require 'crblp_bnBD_alg_lexicon)
(require 'crblp_bnBD_alg_tagger)
(require 'crblp_bnBD_alg_phrasing)
(require 'crblp_bnBD_alg_intonation)
(require 'crblp_bnBD_alg_duration)
(require 'crblp_bnBD_alg_f0model)
(require 'crblp_bnBD_alg_other)
;; ... and others as required

;;;  Ensure we have a festival with the right diphone support compiled in
(require_module 'UniSyn)

(set! crblp_bnBD_alg_lpc_sep 
      (list
       '(name "crblp_bnBD_alg_lpc_sep")
       (list 'index_file (path-append crblp_bnBD_alg_dir "dic/crblp_bnBD.est"))
       '(grouped "false")
       (list 'coef_dir (path-append crblp_bnBD_alg_dir "lpc"))
       (list 'sig_dir  (path-append crblp_bnBD_alg_dir "lpc"))
       '(coef_ext ".lpc")
       '(sig_ext ".res")
       (list 'default_diphone 
	     (string-append
	      (car (cadr (car (PhoneSet.description '(silences)))))
	      "-"
	      (car (cadr (car (PhoneSet.description '(silences)))))))))

(set! crblp_bnBD_alg_lpc_group 
      (list
       '(name "alg_lpc_group")
       (list 'index_file 
	     (path-append crblp_bnBD_alg_dir "group/crblp_bnBD.group"))
       '(grouped "true")
       (list 'default_diphone 
	     (string-append
	      (car (cadr (car (PhoneSet.description '(silences)))))
	      "-"
	      (car (cadr (car (PhoneSet.description '(silences)))))))))

;; Go ahead and set up the diphone db
;(set! crblp_bnBD_alg_db_name (us_diphone_init crblp_bnBD_alg_lpc_sep))
;; Once you've built the group file you can comment out the above and
;; uncomment the following.

(set! crblp_bnBD_alg_db_name (us_diphone_init crblp_bnBD_alg_lpc_group))

(define (crblp_bnBD_alg_diphone_fix utt)
"(crblp_bnBD_alg_diphone_fix UTT)
Map phones to phonological variants if the diphone database supports
them."
  (mapcar
   (lambda (s)
     (let ((name (item.name s)))
       (crblp_bnBD_alg_diphone_fix_phone_name utt s)
       ))
   (utt.relation.items utt 'Segment))
  utt)

(define (crblp_bnBD_alg_diphone_fix_phone_name utt seg)
"(crblp_bnBD_alg_fix_phone_name UTT SEG)
Add the feature diphone_phone_name to given segment with the appropriate
name for constructing a diphone.  Basically adds _ if either side is part
of the same consonant cluster, adds $ either side if in different
syllable for preceding/succeeding vowel syllable."
  (let ((name (item.name seg)))
    (cond
     ((string-equal name "pau") t)
     ((string-equal "-" (item.feat seg 'ph_vc))
      (if (and (member_string name '(r w y l))
	       (member_string (item.feat seg "p.name") '(p t k b d g))
	       (item.relation.prev seg "SylStructure"))
	  (item.set_feat seg "us_diphone_right" (format nil "_%s" name)))
      (if (and (member_string name '(w y l m n p t k))
	       (string-equal (item.feat seg "p.name") 's)
	       (item.relation.prev seg "SylStructure"))
	  (item.set_feat seg "us_diphone_right" (format nil "_%s" name)))
      (if (and (string-equal name 's)
	       (member_string (item.feat seg "n.name") '(w y l m n p t k))
	       (item.relation.next seg "SylStructure"))
	  (item.set_feat seg "us_diphone_left" (format nil "%s_" name)))
      (if (and (string-equal name 'hh)
	       (string-equal (item.feat seg "n.name") 'y))
	  (item.set_feat seg "us_diphone_left" (format nil "%s_" name)))
      (if (and (string-equal name 'y)
	       (string-equal (item.feat seg "p.name") 'hh))
	  (item.set_feat seg "us_diphone_right" (format nil "_%s" name)))
      (if (and (member_string name '(p t k b d g))
	       (member_string (item.feat seg "n.name") '(r w y l))
	       (item.relation.next seg "SylStructure"))
	  (item.set_feat seg "us_diphone_left" (format nil "%s_" name)))
      )
     ((string-equal "ah" (item.name seg))
      (item.set_feat seg "us_diphone" "aa"))

   )))

(define (crblp_bnBD_alg_voice_reset)
  "(crblp_bnBD_alg_voice_reset)
Reset global variables back to previous voice."
  (crblp_bnBD_alg::reset_phoneset)
  (crblp_bnBD_alg::reset_tokenizer)
  (crblp_bnBD_alg::reset_tagger)
  (crblp_bnBD_alg::reset_lexicon)
  (crblp_bnBD_alg::reset_phrasing)
  (crblp_bnBD_alg::reset_intonation)
  (crblp_bnBD_alg::reset_duration)
  (crblp_bnBD_alg::reset_f0model)
  (crblp_bnBD_alg::reset_other)
)

;;;  Full voice definition 
(define (voice_crblp_bnBD_alg_diphone)
"(voice_crblp_bnBD_alg_diphone)
Set speaker to alg in us from crblp."
  ;; Select appropriate phone set
  (crblp_bnBD_alg::select_phoneset)

  ;; Select appropriate tokenization
  (crblp_bnBD_alg::select_tokenizer)

  ;; For part of speech tagging
  (crblp_bnBD_alg::select_tagger)
  
  ;; For pronunciation
  (crblp_bnBD_alg::select_lexicon)

  ;; For Intonation; phrasing: phrase break. Intonation: syllable accent. Duration. f0 model: f0 target point
  (crblp_bnBD_alg::select_phrasing)

  (crblp_bnBD_alg::select_intonation)

  (crblp_bnBD_alg::select_duration)

  (crblp_bnBD_alg::select_f0model)

  ;; Waveform synthesizer: UniSyn diphones
  (set! UniSyn_module_hooks (list crblp_bnBD_alg_diphone_fix))
  (set! us_abs_offset 0.0)
  (set! window_factor 1.0)
  (set! us_rel_offset 0.0)
  (set! us_gain 0.9)

  (Parameter.set 'Synth_Method 'UniSyn)
  (Parameter.set 'us_sigpr 'lpc)
  (us_db_select crblp_bnBD_alg_db_name)

  ;; This is where you can modify power (and sampling rate) if desired
  (set! after_synth_hooks nil)
;  (set! after_synth_hooks
;      (list
;        (lambda (utt)
;          (utt.wave.rescale utt 2.1))))

  ;; set callback to restore some original values changed by this voice
  (set! current_voice_reset crblp_bnBD_alg_voice_reset)

  (set! current-voice 'crblp_bnBD_alg_diphone)
)

(proclaim_voice
 'crblp_bnBD_alg_diphone
 '((language Bangla)
   (gender Male)
   (dialect Bangla)
   (description
    "This voice developed by CRBLP, provides a Bangla (Bengali) male voice using a
     residual excited LPC diphone synthesis method.  It uses a 
     modified CRBLP Lexicon for pronunciations.
     Prosodic phrasing is provided based on function words.  Intonation
     is provided by a CART tree predicting ToBI accents and an F0 
     contour generated from a model trained from natural speech.  The
     duration model is also trained from data using a CART tree."    
    )
   (builtwith festvox-1.3)))

(provide 'crblp_bnBD_alg_diphone)
