;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                                                                       ;;
;;;                Centre for Speech Technology Research                  ;;
;;;                     University of Edinburgh, UK                       ;;
;;;                       Copyright (c) 1996,1997                         ;;
;;;                        All Rights Reserved.                           ;;
;;;                                                                       ;;
;;;  Permission to use, copy, modify, distribute this software and its    ;;
;;;  documentation for research, educational and individual use only, is  ;;
;;;  hereby granted without fee, subject to the following conditions:     ;;
;;;   1. The code must retain the above copyright notice, this list of    ;;
;;;      conditions and the following disclaimer.                         ;;
;;;   2. Any modifications must be clearly marked as such.                ;;
;;;   3. Original authors' names are not deleted.                         ;;
;;;  This software may not be used for commercial purposes without        ;;
;;;  specific prior written permission from the authors.                  ;;
;;;                                                                       ;;
;;;  THE UNIVERSITY OF EDINBURGH AND THE CONTRIBUTORS TO THIS WORK        ;;
;;;  DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING      ;;
;;;  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT   ;;
;;;  SHALL THE UNIVERSITY OF EDINBURGH NOR THE CONTRIBUTORS BE LIABLE     ;;
;;;  FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES    ;;
;;;  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN   ;;
;;;  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,          ;;
;;;  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF       ;;
;;;  THIS SOFTWARE.                                                       ;;
;;;                                                                       ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;					edited by firoj at 2008
;;;
;;;   A hand specified tree to predict zcore durations
;;; The duration of each phone is calculated by acoustic analysis.[paper: ].
;;; This is the average value of eight male and female speaker voice. Nonsense sentenses
;;; were selected to record the text for each phoneme. Each speaker repeated the sentenses by four times.

(set! crblp_bnBD_alg::zdur_tree 
 '
   ((R:SylStructure.parent.R:Syllable.p.syl_break > 1 ) ;; clause initial
    ((1.5))
    ((R:SylStructure.parent.syl_break > 1)   ;; clause final
     ((1.5))
     ((1.0)))))

(set! crblp_bnBD_alg::phone_durs
 ;; should be hand specified
 '(
    (pau 0.0 0.250)	
 ;;   ...  ;; the other phones
 ;;Vowels
;	;	start	end	
(	a	0	0.07465	)
(	aa	0	0.09802	)
(	i	0	0.06899	)
(	u	0	0.0683	)
(	e	0	0.07545	)
(	o	0	0.07574	)
(	a~	0	0.08739	)
(	aa~	0	0.10085	)
(	i~	0	0.08329	)
(	ü	0	0.07585	)
(	o~	0	0.0908	)
(	e~	0	0.0823	)
(	ae	0	0.09089	)
(	ae~	0	0.11998	)
(	ao	0	0.17988	)
(	aai	0	0.16813	)
(	aau	0	0.17059	)
(	aya	0	0.19474	)
(	iu	0	0.14844	)
(	ie	0	0.17687	)
(	io	0	0.14134	)
(	ia	0	0.18423	)
(	ui	0	0.15737	)
(	ua	0	0.17665	)
(	ue	0	0.17079	)
(	uo	0	0.18892	)
(	ei	0	0.17687	)
(	eu	0	0.15657	)
(	eo	0	0.17563	)
(	ea	0	0.17854	)
(	eea	0	0.18839	)
(	oi	0	0.15421	)
(	ou	0	0.17382	)
(	oa	0	0.18091	)
(	oe	0	0.17729	)
				
				
;	;	start	end	
(	k	0	0.102875	)
(	kh	0	0.1135	)
(	g	0	0.07127	)
(	gh	0	0.12745	)
(	ng	0	0.09871	)
(	c	0	0.09523	)
(	ch	0	0.12629	)
(	j	0	0.077885	)
(	jh	0	0.11915	)
(	t	0	0.08079	)
(	th	0	0.106575	)
(	d	0	0.059525	)
(	dh	0	0.116385	)
(	n	0	0.06907	)
(	ta	0	0.09413	)
(	tah	0	0.14157	)
(	da	0	0.065125	)
(	dah	0	0.11498	)
(	p	0	0.083495	)
(	ph	0	0.1236	)
(	b	0	0.06006	)
(	bh	0	0.10629	)
(	m	0	0.10052	)
(	r	0	0.06471	)
(	l	0	0.1007	)
(	sh	0	0.17514	)
(	s	0	0.14726	)
(	h	0	0.1208	)
(	y	0	0.0757	)
(	ra	0	0.04957	)
 )
 ;; But this will fake it until you build a duration model 
 (mapcar
  (lambda (p)
    (list (car p) 0.0 0.100))
  (cadr (assoc_string 'phones (PhoneSet.description ))))
)

(provide 'crblp_bnBD_alg_durdata)
