;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                                                                     ;;;
;;;                     Carnegie Mellon University                      ;;;
;;;                  and Alan W Black and Kevin Lenzo                   ;;;
;;;                      Copyright (c) 1998-2000                        ;;;
;;;                        All Rights Reserved.                         ;;;
;;;                                                                     ;;;
;;; Permission is hereby granted, free of charge, to use and distribute ;;;
;;; this software and its documentation without restriction, including  ;;;
;;; without limitation the rights to use, copy, modify, merge, publish, ;;;
;;; distribute, sublicense, and/or sell copies of this work, and to     ;;;
;;; permit persons to whom this work is furnished to do so, subject to  ;;;
;;; the following conditions:                                           ;;;
;;;  1. The code must retain the above copyright notice, this list of   ;;;
;;;     conditions and the following disclaimer.                        ;;;
;;;  2. Any modifications must be clearly marked as such.               ;;;
;;;  3. Original authors' names are not deleted.                        ;;;
;;;  4. The authors' names are not used to endorse or promote products  ;;;
;;;     derived from this software without specific prior written       ;;;
;;;     permission.                                                     ;;;
;;;                                                                     ;;;
;;; CARNEGIE MELLON UNIVERSITY AND THE CONTRIBUTORS TO THIS WORK        ;;;
;;; DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING     ;;;
;;; ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT  ;;;
;;; SHALL CARNEGIE MELLON UNIVERSITY NOR THE CONTRIBUTORS BE LIABLE     ;;;
;;; FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES   ;;;
;;; WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN  ;;;
;;; AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,         ;;;
;;; ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF      ;;;
;;; THIS SOFTWARE.                                                      ;;;
;;;                                                                     ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Lexicon, LTS and Postlexical rules for crblp_bnBD
;;;
(require 'lts)
;;; Load any necessary files here

(define (crblp_bnBD_addenda)
  "(crblp_bnBD_addenda)
Basic lexicon should (must ?) have basic letters, symbols and punctuation."

;; Basic punctuation must be in with nil pronunciation
(lex.add.entry '("." punc nil))
;(lex.add.entry '("." nn (((p u1 n) 1) ((t o) 0))))
(lex.add.entry '("'" punc nil))
(lex.add.entry '(":" punc nil))
(lex.add.entry '(";" punc nil))
(lex.add.entry '("," punc nil))
;(lex.add.entry '("," nn (((k o1) 1) ((m a) 0))))
(lex.add.entry '("-" punc nil))
(lex.add.entry '("\"" punc nil));"
(lex.add.entry '("`" punc nil))
(lex.add.entry '("?" punc nil))
(lex.add.entry '("!" punc nil))
)



; ;;;  Function called when word not found in lexicon
; ;;;  and you've trained letter to sound rules
; (define (crblp_bnBD_lts_function word features)
;   "(crblp_bnBD_lts_function WORD FEATURES)
; Return pronunciation of word not in lexicon."
;   (if (not boundp 'crblp_bnBD_lts_rules)
;       (require 'crblp_bnBD_lts_rules))
;   (let ((dword (downcase word)) (phones) (syls))
;     (set! phones (lts_predict dword crblp_bnBD_lts_rules))
;     (set! syls (crblp_bnBD_lex_syllabify_phstress phones))
;     (list word features syls)))

(define (crblp_bnBD_is_vowel x)
  (string-equal "+" (phone_feature x "vc")))

(define (crblp_bnBD_contains_vowel l)
  (member_string
   t
   (mapcar (lambda (x) (crblp_bnBD_is_vowel x)) l)))

(define (crblp_bnBD_lex_sylbreak currentsyl remainder)
  "(crblp_bnBD_lex_sylbreak currentsyl remainder)
t if this is a syl break, nil otherwise."
  (cond
   ((not (crblp_bnBD_contains_vowel remainder))
    nil)
   ((not (crblp_bnBD_contains_vowel currentsyl))
    nil)
   (t
    ;; overly naive, I mean wrong
    t))
)

(define (crblp_bnBD_lex_syllabify_phstress phones)
 (let ((syl nil) (syls nil) (p phones) (stress 0))
    (while p
     (set! syl nil)
     (set! stress 0)
     (while (and p (not (crblp_bnBD_lex_sylbreak syl p)))
       (if (string-matches (car p) "xxxx")
           (begin
             ;; whatever you do to identify stress
             (set! stress 1)
             (set syl (cons (car p-stress) syl)))
           (set! syl (cons (car p) syl)))
       (set! p (cdr p)))
     (set! syls (cons (list (reverse syl) stress) syls)))
    (reverse syls)))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; OR: Hand written letter to sound rules
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;  Function called when word not found in lexicon
(define (crblp_bnBD_lts_function word features)
  "(crblp_bnBD_lts_function WORD FEATURES)
Return pronunciation of word not in lexicon."

  ;(format stderr "failed to find pronunciation for %s\n" word)
  (let ((dword (downcase word)) tmp)
    ;; Note you may need to use a letter to sound rule set to do
    ;; casing if the language has non-ascii characters in it.
    (if (lts.in.alphabet word 'crblp_bnBD)
	
	(list
	 word
	 features
	 ;; This syllabification is almost certainly wrong for
	 ;; this language (its not even very good for English)
	 ;; but it will give you something to start off with
	 ;(print (set! tmp (lts.apply word 'crblp_bnBD)) )
	 
	 (lex.syllabify.phstress (lts.apply word 'crblp_bnBD))
	 
	 )
	(begin
	  ;(format stderr "unpronouncable word %s\n" word)
	  ;; Put in a word that means "unknown" with its pronunciation
	  ;'("nepoznat" nil (((N EH P) 0) ((AO Z) 0) ((N AA T) 0)))
	  );begin
	 );if
	 ;(print "pro is: ") (print tmp)
  );let
)

;; You may or may not be able to write a letter to sound rule set for
;; your language.  If its largely lexicon based learning a rule
;; set will be better and easier that writing one (probably).
(lts.ruleset
 crblp_bnBD  
 ;bengali_charset
  (  ;variable defination
     (OCT1  );;1st octact
     (OCT21  );;2nd octact 1 
     (OCT22 );;2nd octact 2
	 
	 (aC                                   )  ;
	 (dVoct21   )
	 (dVoct22                )
	 
     (a_o_v1  ) ; OCT21 a -> o for these vowel
     (a_o_v2     ) ; OCT22 a -> o for these vowel
	 (a_o_v3  ) ; OCT22 a -> o for these vowel
	 (a_o_v4   ) ; OCT22 a -> o for these vowel
	 
     (a_o_v5   ) ; OCT22 a -> o for these vowel
     (a_o_c1    ); OCT21 a -> o for these vowel
	 
	 (e_e_c1     ) ;OCT1 OCT21 ; e -> e
     (e_e_v2      );OCT1 OCT22 ; e -> e
	 (mb  ); ma and ba
	 (mbj    ); ma, ba and ja (for fala) 
	 (mbjr     ); ma, ba, ja,  and ra (for fala)
  );;end of list.ruleset
  
  (;start rules
  
	; a or e become ae if (a e) ja fala
	( # [                ] = ae~)
	( # [                ] = ae~)
    ( # [             ] = ae)
	( # [             ] = ae)
	
	       ;vowel nasal
	( [       ] = a~ ) 	; U+0985
 	( [       ] = aa~ ) 	; U+0986  
	( [       ] = i~ ) 	; U+0987  
	( [       ] = i~ ) 	; U+0988  
	( [       ] = u~ ) 	; U+0989  
	( [       ] = u~ ) 	; U+098a  
	( [       ] = r i~ ) 	; U+098b  
	( [       ] = l i~ ) 		; 
	( [       ] = e~ ) 	; U+098f  
	( [       ] = oi~ ) 	; U+0990  
	( [       ] = o~ ) 	; U+0993  
	( [       ] = ou~ ) 	; U+0994  
	
	
  ; a -> o
	( # [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = o)
	( # [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = o)
	
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = k o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = k o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = kh o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = kh o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = g o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = g o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = gh o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = gh o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = c o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = c o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = ch o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = ch o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = j o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = j o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = jh o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = jh o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = t o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = t o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = th o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = th o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = d o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = d o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = dh o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = dh o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = n o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = n o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = ta o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = ta o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = tah o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = tah o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = da o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = da o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = dah o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = dah o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = n o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = n o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = p o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = p o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = ph o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = ph o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = b o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = b o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = bh o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = bh o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = m o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = m o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = j o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = j o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = r o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = r o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = l o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = l o)
	( [    ] OCT1 OCT21 aC OCT1 OCT21 a_o_v1 = h o)
	( [    ] OCT1 OCT21 aC OCT1 OCT22 a_o_v2 = h o)
	
	;;;; a -> o if [a] c zafala
	( # [    ] OCT1 OCT21 aC       = o)
	( [    ] OCT1 OCT21 aC        = k o)
	( [    ] OCT1 OCT21 aC        = kh o)
	( [    ] OCT1 OCT21 aC        = g o)
	( [    ] OCT1 OCT21 aC        = gh o)
	( [    ] OCT1 OCT21 aC        = c o)
	( [    ] OCT1 OCT21 aC        = ch o)
	( [    ] OCT1 OCT21 aC        = j o)
	( [    ] OCT1 OCT21 aC        = jh o)
	( [    ] OCT1 OCT21 aC        = t o)
	( [    ] OCT1 OCT21 aC        = th o)
	( [    ] OCT1 OCT21 aC        = d o)
	( [    ] OCT1 OCT21 aC        = dh o)
	( [    ] OCT1 OCT21 aC        = n o)
	( [    ] OCT1 OCT21 aC        = ta o)
	( [    ] OCT1 OCT21 aC        = tah o)
	( [    ] OCT1 OCT21 aC        = da o)
	( [    ] OCT1 OCT21 aC        = dah o)
	( [    ] OCT1 OCT21 aC        = n o)
	( [    ] OCT1 OCT21 aC        = p o)
	( [    ] OCT1 OCT21 aC        = ph o)
	( [    ] OCT1 OCT21 aC         = b o)
	( [    ] OCT1 OCT21 aC         = bh o)
	( [    ] OCT1 OCT21 aC         = m o)
	( [    ] OCT1 OCT21 aC        = j o)
	( [    ] OCT1 OCT21 aC        = r o)
	( [    ] OCT1 OCT21 aC        = l o)
	( [    ] OCT1 OCT21 aC        = h o)
	
	;;;; a -> o if  [a] khio
	( # [    ]          = o)
	( [    ]          = k o)
	( [    ]          = k o)
	( [    ]          = kh o)
	( [    ]          = g o)
	( [    ]          = gh o)
	( [    ]          = c o)
	( [    ]          = ch o)
	( [    ]          = j o)
	( [    ]          = jh o)
	( [    ]          = t o)
	( [    ]          = th o)
	( [    ]          = d o)
	( [    ]          = dh o)
	( [    ]          = n o)
	( [    ]          = ta o)
	( [    ]          = tah o)
	( [    ]          = da o)
	( [    ]          = dah o)
	( [    ]          = n o)
	( [    ]          = p o)
	( [    ]          = ph o)
	( [    ]          = b o)
	( [    ]          = bh o)
	( [    ]          = m o)
	( [    ]          = j o)
	( [    ]          = r o)
	( [    ]          = l o)
	( [    ]          = sh o )
	( [    ]          = sh o )
	( [    ]          = sh o )
	( [    ]          = h o)
	( [    ]          = ra o ) 
	( [    ]          = ra o ) 
	( [    ]          = y o ) 
	
	;;;; a -> o if  [a] ja yio
	( # [    ]          = o)
	( [    ]          = k o)
	( [    ]          = kh o)
	( [    ]          = g o)
	( [    ]          = gh o)
	( [    ]          = c o)
	( [    ]          = ch o)
	( [    ]          = j o)
	( [    ]          = jh o)
	( [    ]          = t o)
	( [    ]          = th o)
	( [    ]          = d o)
	( [    ]          = dh o)
	( [    ]          = n o)
	( [    ]          = ta o)
	( [    ]          = tah o)
	( [    ]          = da o)
	( [    ]          = dah o)
	( [    ]          = n o)
	( [    ]          = p o)
	( [    ]          = ph o)
	( [    ]          = b o)
	( [    ]          = bh o)
	( [    ]          = m o)
	( [     ]          = j o)
	( [     ]          = r o)
	( [     ]          = l o)
	( [    ]          = sh o )
	( [    ]          = sh o )
	( [    ]          = sh o )
	( [    ]          = h o)
	( [    ]          = ra o ) 
	( [    ]          = ra o ) 
	( [    ]          = y o ) 
	
	
	;;;; a -> o if # [C a] ra_fala
	( # [          ] = r o)
	( # [          ] = k r o)
	( # [          ] = kh r o)
	( # [          ] = g r o)
	( # [          ] = gh r o)
	( # [          ] = c r o)
	( # [          ] = ch r o)
	( # [          ] = j r o)
	( # [          ] = jh r o)
	( # [          ] = t r o)
	( # [          ] = th r o)
	( # [          ] = d r o)
	( # [          ] = dh r o)
	( # [          ] = n r o)
	( # [          ] = ta r o)
	( # [          ] = tah r o)
	( # [          ] = da r o)
	( # [          ] = dah r o)
	( # [          ] = n r o)
	( # [          ] = p r o)
	( # [          ] = ph r o)
	( # [          ] = b r o)
	( # [          ] = bh r o)
	( # [          ] = m r o)
	( # [          ] = j r o)
	( # [          ] = r r o)
	( # [          ] = l r o)
	( # [          ] = sh r o)
	( # [          ] = sh r o)
	( # [          ] = sh r o)
	( # [          ] = h r o)
	( # [          ] = ra r o) 
	( # [          ] = ra r o) 
	( # [         ] = y r o)
	
	;;;; a -> o if # [C ] ra hasanta (ref)
	( # [    ]       = o)
	( # [    ]       = k o)
	( # [    ]       = kh o)
	( # [    ]       = g o)
	( # [    ]       = gh o)
	( # [    ]       = c o)
	( # [    ]       = ch o)
	( # [    ]       = j o)
	( # [    ]       = jh o)
	( # [    ]       = t o)
	( # [    ]       = th o)
	( # [    ]       = d o)
	( # [    ]       = dh o)
	( # [    ]       = n o)
	( # [    ]       = ta o)
	( # [    ]       = tah o)
	( # [    ]       = da o)
	( # [    ]       = dah o)
	( # [    ]       = n o)
	( # [    ]       = p o)
	( # [    ]       = ph o)
	( # [    ]       = b o)
	( # [    ]       = bh o)
	( # [    ]       = m o)
	( # [    ]       = j o)
	( # [    ]       = r o)
	( # [    ]       = l o)
	( # [    ]       = sh o)
	( # [    ]       = sh o)
	( # [    ]       = sh o)
	( # [    ]       = h o)
	( # [    ]       = ra o) 
	( # [    ]       = ra o) 
	( # [    ]       = y o)
	
	;;;; a -> o if con ( e, o) [C] con
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = k o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = kh o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = g o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = gh o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = c o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = ch o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = j o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = jh o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = t o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = th o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = d o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = dh o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = n o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = ta o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = tah o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = da o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = dah o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = n o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = p o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = ph o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = b o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = bh o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = m o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = j o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = r o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = l o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = sh o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = sh o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = sh o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = h o)
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = ra o) 
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = ra o) 
	( OCT1 OCT21 aC OCT1 OCT22 a_o_v3 [    ] OCT1 OCT21 aC = y o)
	
	;;;; a -> o if con  a [C] con
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = k o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = kh o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = g o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = gh o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = c o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = ch o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = j o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = jh o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = t o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = th o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = d o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = dh o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = n o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = ta o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = tah o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = da o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = dah o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = n o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = p o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = ph o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = b o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = bh o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = m o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = j o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = r o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = l o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = sh o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = sh o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = sh o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = h o)
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = ra o) 
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = ra o) 
	( OCT1 OCT21 aC [    ] OCT1 OCT21 aC = y o)
	
	;;;; a -> o if con  aa [C] con
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = k o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = kh o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = g o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = gh o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = c o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = ch o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = j o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = jh o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = t o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = th o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = d o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = dh o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = n o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = ta o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = tah o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = da o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = dah o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = n o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = p o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = ph o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = b o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = bh o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = m o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = j o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = r o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = l o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = sh o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = sh o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = sh o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = h o)
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = ra o) 
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = ra o) 
	( OCT1 OCT21 aC    [    ] OCT1 OCT21 aC = y o)
	
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
   ; a -> o ; at the end ; if con i ta
	(    [    ] # = ta o)
	(    [    ] # = ta o)
	(    [    ] # = ta o)
	
   ; a -> o ; at the end ; if con (e, i) y
	(    [    ] # = y o)
	(    [    ] # = y o)
	(    [    ] # = y o)
	(    [    ] # = y o)
	
    ; a -> a ; at the end ; if con (a, aa) y
	( OCT1 OCT21 aC [    ] # = y)
	( OCT1 OCT21 aC া [    ] # = y)
	
   ; a -> o ; at the end ; if (ta r) (ta ma)
	( [       ] # = ta a r o)
	( [       ] # = ta a m o)
	
       ; a -> o ;con (oi au ri)
	( OCT1 OCT22 a_o_v5 [    ] # = k o)
	( OCT1 OCT22 a_o_v5 [    ] # = kh o)
	( OCT1 OCT22 a_o_v5 [    ] # = g o)
	( OCT1 OCT22 a_o_v5 [    ] # = gh o)
	( OCT1 OCT22 a_o_v5 [    ] # = c o)
	( OCT1 OCT22 a_o_v5 [    ] # = ch o)
	( OCT1 OCT22 a_o_v5 [    ] # = j o)
	( OCT1 OCT22 a_o_v5 [    ] # = jh o)
	( OCT1 OCT22 a_o_v5 [    ] # = t o)
	( OCT1 OCT22 a_o_v5 [    ] # = th o)
	( OCT1 OCT22 a_o_v5 [    ] # = d o)
	( OCT1 OCT22 a_o_v5 [    ] # = dh o)
	( OCT1 OCT22 a_o_v5 [    ] # = n o)
	( OCT1 OCT22 a_o_v5 [    ] # = ta o)
	( OCT1 OCT22 a_o_v5 [    ] # = tah o)
	( OCT1 OCT22 a_o_v5 [    ] # = da o)
	( OCT1 OCT22 a_o_v5 [    ] # = dah o)
	( OCT1 OCT22 a_o_v5 [    ] # = n o)
	( OCT1 OCT22 a_o_v5 [    ] # = p o)
	( OCT1 OCT22 a_o_v5 [    ] # = ph o)
	( OCT1 OCT22 a_o_v5 [    ] # = b o)
	( OCT1 OCT22 a_o_v5 [    ] # = bh o)
	( OCT1 OCT22 a_o_v5 [    ] # = m o)
	( OCT1 OCT22 a_o_v5 [    ] # = j o)
	( OCT1 OCT22 a_o_v5 [    ] # = r o)
	( OCT1 OCT22 a_o_v5 [    ] # = l o)
	( OCT1 OCT22 a_o_v5 [    ] # = sh o)
	( OCT1 OCT22 a_o_v5 [    ] # = sh o)
	( OCT1 OCT22 a_o_v5 [    ] # = sh o)
	( OCT1 OCT22 a_o_v5 [    ] # = h o)
	( OCT1 OCT22 a_o_v5 [    ] # = ra o) 
	( OCT1 OCT22 a_o_v5 [    ] # = ra o) 
	( OCT1 OCT22 a_o_v5 [    ] # = y o)
	
       ; a -> o ;con (unissor bisorgho )
	( OCT1 OCT21 a_o_c1 [    ] # = k o)
	( OCT1 OCT21 a_o_c1 [    ] # = kh o)
	( OCT1 OCT21 a_o_c1 [    ] # = g o)
	( OCT1 OCT21 a_o_c1 [    ] # = gh o)
	( OCT1 OCT21 a_o_c1 [    ] # = c o)
	( OCT1 OCT21 a_o_c1 [    ] # = ch o)
	( OCT1 OCT21 a_o_c1 [    ] # = j o)
	( OCT1 OCT21 a_o_c1 [    ] # = jh o)
	( OCT1 OCT21 a_o_c1 [    ] # = t o)
	( OCT1 OCT21 a_o_c1 [    ] # = th o)
	( OCT1 OCT21 a_o_c1 [    ] # = d o)
	( OCT1 OCT21 a_o_c1 [    ] # = dh o)
	( OCT1 OCT21 a_o_c1 [    ] # = n o)
	( OCT1 OCT21 a_o_c1 [    ] # = ta o)
	( OCT1 OCT21 a_o_c1 [    ] # = tah o)
	( OCT1 OCT21 a_o_c1 [    ] # = da o)
	( OCT1 OCT21 a_o_c1 [    ] # = dah o)
	( OCT1 OCT21 a_o_c1 [    ] # = n o)
	( OCT1 OCT21 a_o_c1 [    ] # = p o)
	( OCT1 OCT21 a_o_c1 [    ] # = ph o)
	( OCT1 OCT21 a_o_c1 [    ] # = b o)
	( OCT1 OCT21 a_o_c1 [    ] # = bh o)
	( OCT1 OCT21 a_o_c1 [    ] # = m o)
	( OCT1 OCT21 a_o_c1 [    ] # = j o)
	( OCT1 OCT21 a_o_c1 [    ] # = r o)
	( OCT1 OCT21 a_o_c1 [    ] # = l o)
	( OCT1 OCT21 a_o_c1 [    ] # = sh o)
	( OCT1 OCT21 a_o_c1 [    ] # = sh o)
	( OCT1 OCT21 a_o_c1 [    ] # = sh o)
	( OCT1 OCT21 a_o_c1 [    ] # = h o)
	( OCT1 OCT21 a_o_c1 [    ] # = ra o) 
	( OCT1 OCT21 a_o_c1 [    ] # = ra o) 
	( OCT1 OCT21 a_o_c1 [    ] # = y o)
	
	
	; a -> o ; hosonto [ con ]
	(     [    ] # = k o)
	(     [    ] # = kh o)
	(     [    ] # = g o)
	(     [    ] # = gh o)
	(     [    ] # = c o)
	(     [    ] # = ch o)
	(     [    ] # = j o)
	(     [    ] # = jh o)
	(     [    ] # = t o)
	(     [    ] # = th o)
	(     [    ] # = d o)
	(     [    ] # = dh o)
	(     [    ] # = n o)
	(     [    ] # = ta o)
	(     [    ] # = tah o)
	(     [    ] # = da o)
	(     [    ] # = dah o)
	(     [    ] # = n o)
	(     [    ] # = p o)
	(     [    ] # = ph o)
	(     [    ] # = b o)
	(     [    ] # = bh o)
	(     [    ] # = m o)
	(     [    ] # = j o)
	(     [    ] # = r o)
	(     [    ] # = l o)
	(     [    ] # = sh o)
	(     [    ] # = sh o)
	(     [    ] # = sh o)
	(     [    ] # = h o)
	(     [    ] # = ra o) 
	(     [    ] # = ra o) 
	(     [    ] # = y o)
	
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	;;;;
	;;;;				e -> ae (some times e)
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
		
	(# [    ] OCT1 OCT21 e_e_c1 = e)
	(# [    ] OCT1 OCT21 aC OCT1 OCT21     = e)
	(# [    ] OCT1 OCT21 aC OCT1 OCT22 e_e_v2 = e)
	(# [    ]    = e)
	(# OCT1 OCT21 aC [    ] OCT1 OCT21 e_e_c1 = e)
	(# OCT1 OCT21 aC [    ] OCT1 OCT21 aC     = e)
	(# OCT1 OCT21 aC [    ] OCT1 OCT21 aC    OCT1 OCT21 aC    = e)
	(# OCT1 OCT21 aC [    ] OCT1 OCT21 aC    OCT1 OCT21 aC    = e)
	(# OCT1 OCT21 aC [    ] OCT1 OCT21 aC    OCT1 OCT21 aC    = e)
	(# OCT1 OCT21 aC [    ] OCT1 OCT21 aC    OCT1 OCT21 aC    = e)
	(# OCT1 OCT21 aC [    ] OCT1 OCT21 aC OCT1 OCT22 e_e_v2 = e)
	(# OCT1 OCT21 aC [    ]    = e)

	(# OCT1 OCT21 aC [    ]    OCT1 OCT21 aC    = e)
	(# OCT1 OCT21 aC [    ]    OCT1 OCT21 aC    = e)
	(# OCT1 OCT21 aC [    ]    OCT1 OCT21 aC    = e)
	(# OCT1 OCT21 aC [    ]    OCT1 OCT21 aC    = e)
	(# OCT1 OCT21 aC [    ]          OCT1 OCT21 aC    = e)
	(# OCT1 OCT21 aC [    ]          OCT1 OCT21 aC    = e)
	(# OCT1 OCT21 aC [    ]          OCT1 OCT21 aC    = e)
	(# OCT1 OCT21 aC [    ]          OCT1 OCT21 aC    = e)
	(# OCT1 OCT21 aC [    ]    = ae)
	(# OCT1 OCT21 aC [    ]    = ae)
	
	;------------ end -------------- e -> ae ---------------------------------
       
	   
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	;;
	;;			Consonant (single also compaund)
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	( [     ]       = n)
	( [    ]       = n)
	( [    ]       = n)
	( [    ]       = n)
	(       [    ] = n)
	(    [    ] = n)

	; khio (k + sh)
	( # [          ] OCT1 OCT21 dVoct21 = kh)
	( # [          ] OCT1 OCT22 dVoct22 = kh)  
	( # [          ]  = kh a) 
	( [          ] OCT1 OCT21 dVoct21 = k kh) 
	( [          ] OCT1 OCT22 dVoct22 = k kh) 
	( [          ] = k kh o) 
	
	(# [             ] = g ae~)
	( [             ] = g g ae~)
	( [          ] = g g o~)
	
	
	;; bisorgho
	(    [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	(     [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	(    [    ] # = h )
	;;consonent followed by bisorgho
	( [    ]    = k o ) 	; U+0995  Bengali Letter Ka
	( [    ]    = kh o ) 	; U+0996  Bengali Letter Kha
	( [    ]    = g o ) 	; U+0997  Bengali Letter Ga
	( [    ]    = gh o ) 	; U+0998  Bengali Letter Gha
	;( [   ]    = ng o ) 	; U+0999  Bengali Letter Nga
	( [    ]    = c o ) 	; U+099a  Bengali Letter Ca
	( [    ]    = ch o ) 	; U+099b  Bengali Letter Cha
	( [    ]    = j o ) 	; U+099c  Bengali Letter Ja
	( [    ]    = jh o ) 	; U+099d  Bengali Letter Jha
	;( [    ]    =  o ) 	; U+099e  Bengali Letter Nya
	( [    ]    = t o ) 	; U+099f  Bengali Letter Tta
	( [    ]    = th o ) 	; U+09a0  Bengali Letter Ttha
	( [    ]    = d o ) 	; U+09a1  Bengali Letter Dda
	( [    ]    = dh o ) 	; U+09a2  Bengali Letter Ddha
	( [    ]    = n o ) 	; U+09a3  Bengali Letter Nna
	( [    ]    = ta o ) 	; U+09a4  Bengali Letter Ta
	( [    ]    = tah o ) 	; U+09a5  Bengali Letter Tha
	( [    ]    = da o ) 	; U+09a6  Bengali Letter Da
	( [    ]    = dah o ) 	; U+09a7  Bengali Letter Dha
	( [    ]    = n o ) 	; U+09a8  Bengali Letter Na
	( [    ]    = p o ) 	; U+09aa  Bengali Letter Pa
	( [    ]    = ph o ) 	; U+09ab  Bengali Letter Pha
	( [    ]    = b o ) 	; U+09ac  Bengali Letter Ba
	( [    ]    = bh o ) 	; U+09ad  Bengali Letter Bha
	( [    ]    = m o ) 	; U+09ae  Bengali Letter Ma
	( [    ]    = j o ) 	; U+09af  Bengali Letter Ya
	( [    ]    = r o ) 	; U+09b0  Bengali Letter Ra
	( [    ]    = l o ) 	; U+09b2  Bengali Letter La
	( [    ]    = sh o ) 	; U+09b6  Bengali Letter Sa
	( [    ]    = sh o ) 	; U+09b7  Bengali Letter Sa
	( [    ]    = sh o ) 	; U+09b8  Bengali Letter Sa
	( [    ]    = h o )	; U+09b9 Bengali Letter Ha
	( [    ]    = ra o ) 	; U+09dc  Bengali Letter Ra
	( [    ]    = ra o ) 	; U+09dd  Bengali Letter Ra
	;( [    ]    = y o ) 	; U+09df  Bengali Letter Ya
	;; bisorgho followed by consonent     
	( [    ]     = k ) 	; U+0995  Bengali Letter Ka
	( [    ]     = k ) 	; U+0996  Bengali Letter Kha
	( [    ]     = g ) 	; U+0997  Bengali Letter Ga
	( [    ]     = g ) 	; U+0998  Bengali Letter Gha
	;( [    ]     = ng ) 	; U+0999  Bengali Letter Nga
	( [    ]     = c ) 	; U+099a  Bengali Letter Ca
	( [    ]     = c ) 	; U+099b  Bengali Letter Cha
	( [    ]     = j ) 	; U+099c  Bengali Letter Ja
	( [    ]     = j ) 	; U+099d  Bengali Letter Jha
	;( [    ]     =  ) 	; U+099e  Bengali Letter Nya
	( [    ]     = t ) 	; U+099f  Bengali Letter Tta
	( [    ]     = t ) 	; U+09a0  Bengali Letter Ttha
	( [    ]     = d ) 	; U+09a1  Bengali Letter Dda
	( [    ]     = d ) 	; U+09a2  Bengali Letter Ddha
	( [    ]     = n ) 	; U+09a3  Bengali Letter Nna
	( [    ]     = ta ) 	; U+09a4  Bengali Letter Ta
	( [    ]     = ta ) 	; U+09a5  Bengali Letter Tha
	( [    ]     = da ) 	; U+09a6  Bengali Letter Da
	( [    ]     = da ) 	; U+09a7  Bengali Letter Dha
	( [    ]     = n ) 	; U+09a8  Bengali Letter Na
	( [    ]     = p ) 	; U+09aa  Bengali Letter Pa
	( [    ]     = p ) 	; U+09ab  Bengali Letter Pha
	( [    ]     = b ) 	; U+09ac  Bengali Letter Ba
	( [    ]     = b ) 	; U+09ad  Bengali Letter Bha
	( [    ]     = m ) 	; U+09ae  Bengali Letter Ma
	( [    ]     = j ) 	; U+09af  Bengali Letter Ya
	( [    ]     = r ) 	; U+09b0  Bengali Letter Ra
	( [    ]     = l ) 	; U+09b2  Bengali Letter La
	( [    ]     = sh ) 	; U+09b6  Bengali Letter Sa
	( [    ]     = sh ) 	; U+09b7  Bengali Letter Sa
	( [    ]     = sh ) 	; U+09b8  Bengali Letter Sa
	( [    ]     = h )	; U+09b9 Bengali Letter Ha
	( [    ]     = ra ) 	; U+09dc  Bengali Letter Ra
	( [    ]     = ra ) 	; U+09dd  Bengali Letter Ra
	;( [    ]     = y ) 	; U+09df  Bengali Letter Ya
	
	;;; rule for h 
	( [          ] OCT1 OCT21 dVoct21 = r h )
	( [          ] OCT1 OCT22 dVoct22 = r h )
	( [          ]  = r h o)
	( [          ] OCT1 OCT21 dVoct21 = n n h )
	( [          ] OCT1 OCT22 dVoct22 = n n h )
	( [          ]  = n n h o)
	( [          ] OCT1 OCT21 dVoct21 = n n h )
	( [          ] OCT1 OCT22 dVoct22 = n n h )
	( [          ]  = n n h o)
	( [          ] OCT1 OCT21 dVoct21 = m h )
	( [          ] OCT1 OCT22 dVoct22 = m h )
	( [          ]  = m h o)
	( [          ] OCT1 OCT21 dVoct21 = j jh h )
	( [          ] OCT1 OCT22 dVoct22 = j jh h )
	( [          ]  = j jh h o)
	( [          ] OCT1 OCT21 dVoct21 = l l h )
	( [          ] OCT1 OCT22 dVoct22 = l l h )
	( [          ]  = l l h o)
	( [          ]  OCT1 OCT21 dVoct21 = o bh )
	( [          ]  OCT1 OCT22 dVoct22 = o bh )
	( [          ]  = o bh o)
	
	  ; ja fala after the 1st char
	( # [          ] OCT1 OCT21 aC    = k e )
	( # [             ] = k ae )
	( # [          ] OCT1 OCT21 dVoct21 = k )
	( # [          ] OCT1 OCT22 dVoct22 = k )
	( # [          ] = k ae )
	( # [          ] OCT1 OCT21 aC    = kh e )
	( # [             ] = kh ae )
	( # [          ] OCT1 OCT21 dVoct21 = kh )
	( # [          ] OCT1 OCT22 dVoct22 = kh )
	( # [          ] = kh ae )
	( # [          ] OCT1 OCT21 aC    = g e )
	( # [             ] = g ae )
	( # [          ] OCT1 OCT21 dVoct21 = g )
	( # [          ] OCT1 OCT22 dVoct22 = g )
	( # [          ] = g ae )
	( # [          ] OCT1 OCT21 aC    = gh e )
	( # [             ] = gh ae )
	( # [          ] OCT1 OCT21 dVoct21 = gh )
	( # [          ] OCT1 OCT22 dVoct22 = gh )
	( # [          ] = gh ae )
	;( # [          ] OCT1 OCT21 aC    = ng e )
	;( # [             ] = ng ae )
	;( # [          ] OCT1 OCT21 dVoct21 = ng )
	;( # [          ] OCT1 OCT22 dVoct22 = ng )
	;( # [          ] = ng ae )
	( # [          ] OCT1 OCT21 aC    = c e )
	( # [             ] = c ae )
	( # [          ] OCT1 OCT21 dVoct21 = c )
	( # [          ] OCT1 OCT22 dVoct22 = c )
	( # [          ] = c ae )
	( # [          ] OCT1 OCT21 aC    = ch e )
	( # [             ] = ch ae )
	( # [          ] OCT1 OCT21 dVoct21 = ch )
	( # [          ] OCT1 OCT22 dVoct22 = ch )
	( # [          ] = ch ae )
	( # [          ] OCT1 OCT21 aC    = j e )
	( # [             ] = j ae )
	( # [          ] OCT1 OCT21 dVoct21 = j )
	( # [          ] OCT1 OCT22 dVoct22 = j )
	( # [          ] = j ae )
	( # [          ] OCT1 OCT21 aC    = jh e )
	( # [             ] = jh ae )
	( # [          ] OCT1 OCT21 dVoct21 = jh )
	( # [          ] OCT1 OCT22 dVoct22 = jh )
	( # [          ] = jh ae )
	;( # [          ] OCT1 OCT21 aC    =   e )
	;( # [             ] =   ae )
	;( # [          ] OCT1 OCT21 dVoct21 =   )
	;( # [          ] OCT1 OCT22 dVoct22 =   )
	;( # [          ] =   ae )
	( # [          ] OCT1 OCT21 aC    = t e )
	( # [             ] = t ae )
	( # [          ] OCT1 OCT21 dVoct21 = t )
	( # [          ] OCT1 OCT22 dVoct22 = t )
	( # [          ] = t ae )
	( # [          ] OCT1 OCT21 aC    = ta e )
	( # [             ] = ta ae )
	( # [          ] OCT1 OCT21 dVoct21 = ta )
	( # [          ] OCT1 OCT22 dVoct22 = ta )
	( # [          ] = ta ae )
	( # [          ] OCT1 OCT21 aC    = d e )
	( # [             ] = d ae )
	( # [          ] OCT1 OCT21 dVoct21 = d )
	( # [          ] OCT1 OCT22 dVoct22 = d )
	( # [          ] = d ae )
	( # [          ] OCT1 OCT21 aC    = da e )
	( # [             ] = da ae )
	( # [          ] OCT1 OCT21 dVoct21 = da )
	( # [          ] OCT1 OCT22 dVoct22 = da )
	( # [          ] = da ae )
	( # [          ] OCT1 OCT21 aC    = n e )
	( # [             ] = n ae )
	( # [          ] OCT1 OCT21 dVoct21 = n )
	( # [          ] OCT1 OCT22 dVoct22 = n )
	( # [          ] = n ae )
	( # [          ] OCT1 OCT21 aC    = ta e )
	( # [             ] = ta ae )
	( # [          ] OCT1 OCT21 dVoct21 = ta )
	( # [          ] OCT1 OCT22 dVoct22 = ta )
	( # [          ] = ta ae )
	( # [         ] OCT1 OCT21 aC    = tah e )
	( # [              ] = tah ae )
	( # [          ] OCT1 OCT21 dVoct21 = tah )
	( # [          ] OCT1 OCT22 dVoct22 = tah )
	( # [          ] = tah ae )
	( # [          ] OCT1 OCT21 aC    = da e )
	( # [             ] = da ae )
	( # [          ] OCT1 OCT21 dVoct21 = da )
	( # [          ] OCT1 OCT22 dVoct22 = da )
	( # [          ] = da ae )
	( # [          ] OCT1 OCT21 aC    = dah e )
	( # [             ] = dah ae )
	( # [          ] OCT1 OCT21 dVoct21 = dah )
	( # [          ] OCT1 OCT22 dVoct22 = dah )
	( # [          ] = dah ae )
	( # [          ] OCT1 OCT21 aC    = n e )
	( # [              ] = n ae )
	( # [          ] OCT1 OCT21 dVoct21 = n )
	( # [          ] OCT1 OCT22 dVoct22 = n )
	( # [          ] = n ae )
	( # [          ] OCT1 OCT21 aC    = p e )
	( # [             ] = p ae )
	( # [          ] OCT1 OCT21 dVoct21 = p )
	( # [          ] OCT1 OCT22 dVoct22 = p )
	( # [          ] = p ae )
	( # [          ] OCT1 OCT21 aC    = ph e )
	( # [             ] = ph ae )
	( # [          ] OCT1 OCT21 dVoct21 = ph )
	( # [          ] OCT1 OCT22 dVoct22 = ph )
	( # [          ] = ph ae )
	( # [          ] OCT1 OCT21 aC    = b e )
	( # [             ] = b ae )
	( # [          ] OCT1 OCT21 dVoct21 = b )
	( # [          ] OCT1 OCT22 dVoct22 = b )
	( # [          ] = b ae )
	( # [          ] OCT1 OCT21 aC    = bh e )
	( # [             ] = bh ae )
	( # [          ] OCT1 OCT21 dVoct21 = bh )
	( # [          ] OCT1 OCT22 dVoct22 = bh )
	( # [          ] = bh ae )
	( # [          ] OCT1 OCT21 aC    = m e )
	( # [             ] = m ae )
	( # [          ] OCT1 OCT21 dVoct21 = m )
	( # [          ] OCT1 OCT22 dVoct22 = m )
	( # [          ] = m ae )
	( # [          ] OCT1 OCT21 aC    = j e )
	( # [             ] = j ae )
	( # [          ] OCT1 OCT21 dVoct21 = j )
	( # [          ] OCT1 OCT22 dVoct22 = j )
	( # [          ] = j ae )
	( # [                ] OCT1 OCT21 aC    = r e ) 
	( # [                   ] = r ae )
	( # [                ] OCT1 OCT21 dVoct21 = r )
	( # [                ] OCT1 OCT22 dVoct22 = r )
	( # [                ] = r ae )
	( # [          ] OCT1 OCT21 aC    = l e )
	( # [             ] = l ae )
	( # [          ] OCT1 OCT21 dVoct21 = l )
	( # [          ] OCT1 OCT22 dVoct22 = l )
	( # [          ] = l ae )
	( # [          ] OCT1 OCT21 aC    = sh e )
	( # [             ] = sh ae )
	( # [          ] OCT1 OCT21 dVoct21 = sh )
	( # [          ] OCT1 OCT22 dVoct22 = sh )
	( # [          ] = sh ae )
	( # [          ] OCT1 OCT21 aC    = sh e )
	( # [             ] = sh ae )
	( # [          ] OCT1 OCT21 dVoct21 = sh )
	( # [          ] OCT1 OCT22 dVoct22 = sh )
	( # [          ] = sh ae )
	( # [          ] OCT1 OCT21 aC    = sh e )
	( # [             ] = sh ae )
	( # [          ] OCT1 OCT21 dVoct21 = sh )
	( # [          ] OCT1 OCT22 dVoct22 = sh )
	( # [          ] = sh ae )
	( # [          ] OCT1 OCT21 aC    = h e )
	( # [             ] = h ae )
	( # [          ] OCT1 OCT21 dVoct21 = h )
	( # [          ] OCT1 OCT22 dVoct22 = h )
	( # [          ] = h ae )
	( # [          ] OCT1 OCT21 aC    = ra e )
	( # [             ] = ra ae )
	( # [          ] OCT1 OCT21 dVoct21 = ra )
	( # [          ] OCT1 OCT22 dVoct22 = ra )
	( # [          ] = ra ae )
	( # [          ] OCT1 OCT21 aC    = ra e )
	( # [             ] = ra ae )
	( # [          ] OCT1 OCT21 dVoct21 = ra )
	( # [          ] OCT1 OCT22 dVoct22 = ra )
	( # [          ] = ra ae )
	;( # [          ] OCT1 OCT21 aC    = y e )
	;( # [             ] = y ae )
	;( # [          ] OCT1 OCT21 dVoct21 = y )
	;( # [          ] OCT1 OCT22 dVoct22 = y )
	;( # [          ] = y ae )
	
	
	 ;ba fala, ma fala, and ja fala after a compaund cahr (no sound of them)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = k )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = k )
	( OCT1 OCT21 aC [            mbj ] = k o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = kh )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = kh )
	( OCT1 OCT21 aC [            mbj ] = kh o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = g )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = g )
	( OCT1 OCT21 aC [            mbj ] = g o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = gh )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = gh )
	( OCT1 OCT21 aC [            mbj ] = gh o)
	;( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = ng )
	;( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = ng )
	;( OCT1 OCT21 aC [            mbj ] = ng o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = c )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = c )
	( OCT1 OCT21 aC [            mbj ] = c o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = ch )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = ch )
	( OCT1 OCT21 aC [            mbj ] = ch o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = j )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = j )
	( OCT1 OCT21 aC [            mbj ] = j o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = jh )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = jh )
	( OCT1 OCT21 aC [            mbj ] = jh o)
	;( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 =   )
	;( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 =   )
	;( OCT1 OCT21 aC [            mbj ] =   o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = t )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = t )
	( OCT1 OCT21 aC [            mbj ] = t o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = th )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = th )
	( OCT1 OCT21 aC [            mbj ] = th o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = d )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = d )
	( OCT1 OCT21 aC [            mbj ] = d o)
	( OCT1 OCT21 aC [           mbj ] OCT1 OCT21 dVoct21 = dh )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = dh )
	( OCT1 OCT21 aC [            mbj ] = dh o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = n )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = n )
	( OCT1 OCT21 aC [            mbj ] = n o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = ta )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = ta )
	( OCT1 OCT21 aC [             mbj ] = ta o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = tah )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = tah )
	( OCT1 OCT21 aC [            mbj ] = tah o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = da )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = da )
	( OCT1 OCT21 aC [            mbj ] = da o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = dah )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = dah )
	( OCT1 OCT21 aC [            mbj ] = dah o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = n )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = n )
	( OCT1 OCT21 aC [            mbj ] = n o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = p )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = p )
	( OCT1 OCT21 aC [            mbj ] = p o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = ph )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = ph )
	( OCT1 OCT21 aC [            mbj ] = ph o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = b )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = b )
	( OCT1 OCT21 aC [            mbj ] = b o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = bh )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = bh )
	( OCT1 OCT21 aC [            mbj ] = bh o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = m )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = m )
	( OCT1 OCT21 aC [            mbj ] = m o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = j )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = j )
	( OCT1 OCT21 aC [            mbj ] = j o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = r )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = r )
	( OCT1 OCT21 aC [            mbj ] = r o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = l )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = l )
	( OCT1 OCT21 aC [            mbj ] = l o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = sh )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = sh )
	( OCT1 OCT21 aC [            mbj ] = sh o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = sh )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = sh )
	( OCT1 OCT21 aC [            mbj ] = sh o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = sh )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = sh )
	( OCT1 OCT21 aC [            mbj ] = sh o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = h )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = h )
	( OCT1 OCT21 aC [            mbj ] = h o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = ra )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = ra )
	( OCT1 OCT21 aC [            mbj ] = ra o)
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT21 dVoct21 = ra )
	( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = ra )
	( OCT1 OCT21 aC [            mbj ] = ra o)
	;( OCT1 OCT21 aC [             mbj ] OCT1 OCT21 dVoct21 = y )
	;( OCT1 OCT21 aC [            mbj ] OCT1 OCT22 dVoct22 = y )
	;( OCT1 OCT21 aC [            mbj ] = y o)
	
	 ;ra fala after a compaund cahr
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = k r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = k r )
	( OCT1 OCT21 aC [             ] = k  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = kh r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = kh r )
	( OCT1 OCT21 aC [             ] = kh  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = g r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = g r )
	( OCT1 OCT21 aC [             ] = g  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = gh r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = gh r )
	( OCT1 OCT21 aC [             ] = gh  r o)
	;( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = ng r )
	;( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = ng r )
	;( OCT1 OCT21 aC [             ] = ng  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = c r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = c r )
	( OCT1 OCT21 aC [             ] = c  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = ch r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = ch r )
	( OCT1 OCT21 aC [             ] = ch  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = j r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = j r )
	( OCT1 OCT21 aC [             ] = j  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = jh r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = jh r )
	( OCT1 OCT21 aC [             ] = jh  r o)
	;( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 =   r )
	;( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 =   r )
	;( OCT1 OCT21 aC [              ] =  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = t r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = t r )
	( OCT1 OCT21 aC [             ] = t  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = th r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = th r )
	( OCT1 OCT21 aC [             ] = th  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = d r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = d r )
	( OCT1 OCT21 aC [             ] = d  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = dh r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = dh r )
	( OCT1 OCT21 aC [             ] = dh  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = n r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = n r )
	( OCT1 OCT21 aC [             ] = n  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = ta r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = ta r )
	( OCT1 OCT21 aC [             ] = ta  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = tah r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = tah r )
	( OCT1 OCT21 aC [             ] = tah  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = da r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = da r )
	( OCT1 OCT21 aC [             ] = da  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = dah r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = dah r )
	( OCT1 OCT21 aC [             ] = dah  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = n r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = n r )
	( OCT1 OCT21 aC [             ] = n  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = p r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = p r )
	( OCT1 OCT21 aC [             ] = p  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = ph r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = ph r )
	( OCT1 OCT21 aC [             ] = ph  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = b r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = b r )
	( OCT1 OCT21 aC [             ] = b  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = bh r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = bh r )
	( OCT1 OCT21 aC [             ] = bh  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = m r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = m r )
	( OCT1 OCT21 aC [             ] = m  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = j r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = j r )
	( OCT1 OCT21 aC [             ] = j  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = r r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = r r )
	( OCT1 OCT21 aC [             ] = r  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = l r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = l r )
	( OCT1 OCT21 aC [             ] = l  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = sh r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = sh r )
	( OCT1 OCT21 aC [             ] = sh  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = sh r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = sh r )
	( OCT1 OCT21 aC [             ] = sh  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = sh r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = sh r )
	( OCT1 OCT21 aC [             ] = sh  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = h r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = h r )
	( OCT1 OCT21 aC [             ] = h  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = ra r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = ra r )
	( OCT1 OCT21 aC [             ] = ra  r o)
	( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = ra r )
	( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = ra r )
	( OCT1 OCT21 aC [             ] = ra  r o)
	;( OCT1 OCT21 aC [             ] OCT1 OCT21 dVoct21 = y r )
	;( OCT1 OCT21 aC [             ] OCT1 OCT22 dVoct22 = y r )
	;( OCT1 OCT21 aC [             ] = y  r o)
	
	 ; ba fala rule ( no sound of ba after *u da*)
	( # [       ]       = u da)
	 
	 ;ba fala and ma fala for initial (in both  cases the sound of ba and ma is empty)
	( # [         mb ] OCT1 OCT21 dVoct21 = k )
	( # [         mb ] OCT1 OCT22 dVoct22 = k )
	( # [         mb ] = k a )
	( # [         mb ] OCT1 OCT21 dVoct21 = kh )
	( # [         mb ] OCT1 OCT22 dVoct22 = kh )
	( # [         mb ] = kh a )
	( # [         mb ] OCT1 OCT21 dVoct21 = g )
	( # [         mb ] OCT1 OCT22 dVoct22 = g )
	( # [         mb ] = g a )
	( # [         mb ] OCT1 OCT21 dVoct21 = gh )
	( # [         mb ] OCT1 OCT22 dVoct22 = gh )
	( # [         mb ] = gh a )
	;( # [         mb ] OCT1 OCT21 dVoct21 = ng )
	;( # [         mb ] OCT1 OCT22 dVoct22 = ng )
	;( # [         mb ] = ng a )
	( # [         mb ] OCT1 OCT21 dVoct21 = c )
	( # [         mb ] OCT1 OCT22 dVoct22 = c )
	( # [         mb ] = c a )
	( # [         mb ] OCT1 OCT21 dVoct21 = ch )
	( # [         mb ] OCT1 OCT22 dVoct22 = ch )
	( # [         mb ] = ch a )
	( # [         mb ] OCT1 OCT21 dVoct21 = j )
	( # [         mb ] OCT1 OCT22 dVoct22 = j )
	( # [         mb ] = j a )
	( # [         mb ] OCT1 OCT21 dVoct21 = jh )
	( # [         mb ] OCT1 OCT22 dVoct22 = jh )
	( # [         mb ] = jh a )
	;( # [         mb ] OCT1 OCT21 dVoct21 =   )
	;( # [         mb ] OCT1 OCT22 dVoct22 =   )
	;( # [         mb ] =   a )
	( # [         mb ] OCT1 OCT21 dVoct21 = t )
	( # [         mb ] OCT1 OCT22 dVoct22 = t )
	( # [         mb ] = t a )
	( # [         mb ] OCT1 OCT21 dVoct21 = th )
	( # [         mb ] OCT1 OCT22 dVoct22 = th )
	( # [         mb ] = th a )
	( # [         mb ] OCT1 OCT21 dVoct21 = d )
	( # [         mb ] OCT1 OCT22 dVoct22 = d )
	( # [         mb ] = d a )
	( # [         mb ] OCT1 OCT21 dVoct21 = dh )
	( # [         mb ] OCT1 OCT22 dVoct22 = dh )
	( # [         mb ] = dh a )
	( # [         mb ] OCT1 OCT21 dVoct21 = n )
	( # [         mb ] OCT1 OCT22 dVoct22 = n )
	( # [         mb ] = n a )
	( # [         mb ] OCT1 OCT21 dVoct21 = ta )
	( # [         mb ] OCT1 OCT22 dVoct22 = ta )
	( # [         mb ] = ta a )
	( # [         mb ] OCT1 OCT21 dVoct21 = tah )
	( # [         mb ] OCT1 OCT22 dVoct22 = tah )
	( # [         mb ] = tah a )
	( # [         mb ] OCT1 OCT21 dVoct21 = da )
	( # [         mb ] OCT1 OCT22 dVoct22 = da )
	( # [         mb ] = da a )
	( # [         mb ] OCT1 OCT21 dVoct21 = dah )
	( # [         mb ] OCT1 OCT22 dVoct22 = dah )
	( # [         mb ] = dah a )
	( # [         mb ] OCT1 OCT21 dVoct21 = n )
	( # [         mb ] OCT1 OCT22 dVoct22 = n )
	( # [         mb ] = n a )
	( # [         mb ] OCT1 OCT21 dVoct21 = p )
	( # [         mb ] OCT1 OCT22 dVoct22 = p )
	( # [         mb ] = p a )
	( # [         mb ] OCT1 OCT21 dVoct21 = ph )
	( # [         mb ] OCT1 OCT22 dVoct22 = ph )
	( # [         mb ] = ph a )
	( # [         mb ] OCT1 OCT21 dVoct21 = b )
	( # [         mb ] OCT1 OCT22 dVoct22 = b )
	( # [         mb ] = b a )
	( # [         mb ] OCT1 OCT21 dVoct21 = bh )
	( # [         mb ] OCT1 OCT22 dVoct22 = bh )
	( # [         mb ] = bh a )
	( # [         mb ] OCT1 OCT21 dVoct21 = m )
	( # [         mb ] OCT1 OCT22 dVoct22 = m )
	( # [         mb ] = m a )
	( # [         mb ] OCT1 OCT21 dVoct21 = j )
	( # [         mb ] OCT1 OCT22 dVoct22 = j )
	( # [         mb ] = j a )
	;( # [         mb ] OCT1 OCT21 dVoct21 = r )
	;( # [         mb ] OCT1 OCT22 dVoct22 = r )
	;( # [         mb ] = r a )
	( # [         mb ] OCT1 OCT21 dVoct21 = l )
	( # [         mb ] OCT1 OCT22 dVoct22 = l )
	( # [         mb ] = l a )
	( # [         mb ] OCT1 OCT21 dVoct21 = sh )
	( # [         mb ] OCT1 OCT22 dVoct22 = sh )
	( # [         mb ] = sh a )
	( # [         mb ] OCT1 OCT21 dVoct21 = sh )
	( # [         mb ] OCT1 OCT22 dVoct22 = sh )
	( # [         mb ] = sh a )
	( # [         mb ] OCT1 OCT21 dVoct21 = sh ) 
	( # [         mb ] OCT1 OCT22 dVoct22 = sh )
	( # [         mb ] = sh a )
	( # [         mb ] OCT1 OCT21 dVoct21 = h )
	( # [         mb ] OCT1 OCT22 dVoct22 = h )
	( # [         mb ] = h a )
	( # [         mb ] OCT1 OCT21 dVoct21 = ra )
	( # [         mb ] OCT1 OCT22 dVoct22 = ra )
	( # [         mb ] = ra a )
	( # [         mb ] OCT1 OCT21 dVoct21 = ra )
	( # [         mb ] OCT1 OCT22 dVoct22 = ra )
	( # [         mb ] = ra a )
	;( # [         mb ] OCT1 OCT21 dVoct21 = y )
	;( # [         mb ] OCT1 OCT22 dVoct22 = y )
	;( # [         mb ] = y a )
	 
	 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	 ;ba fala, ma fala, ra fala (), and ja fala () for middle or end	(the sound of the consonant with fala become 2wice)
	( [         mbjr ] OCT1 OCT21 dVoct21 = k k)
	( [         mbjr ] OCT1 OCT22 dVoct22 = k k)
	( [         mbjr ] # = k k o)
	( [         mbjr ] = k k a)
	( [         mbjr ] OCT1 OCT21 dVoct21 = k kh)
	( [         mbjr ] OCT1 OCT22 dVoct22 = k kh)
	( [         mbjr ] # = k kh o)
	( [         mbjr ] = k kh a)
	; continue: ba and ma both become smae after ga, so ignoring this
	; but only ja fala and ra fala () is here
	( [          ] OCT1 OCT21 dVoct21 = g g) 
	( [          ] OCT1 OCT22 dVoct22 = g g) 
	( [          ] # = g g o) 
	( [          ] = g g a) 
	( [          ] OCT1 OCT21 dVoct21 = g g) 
	( [          ] OCT1 OCT22 dVoct22 = g g) 
	( [          ] # = g g o) 
	( [          ] = g g a) 
	; continue as main rule 
	( [         mbjr ] OCT1 OCT21 dVoct21 = g gh)
	( [         mbjr ] OCT1 OCT22 dVoct22 = g gh)
	( [         mbjr ] # = g gh o)
	( [         mbjr ] = g gh a)
	; continue: ma become same after ng, so its aonly for ba ()
	( [          ] OCT1 OCT21 dVoct21 = ng ng) 
	( [          ] OCT1 OCT22 dVoct22 = ng ng)
	( [          ] # = ng ng o)
	( [          ] = ng ng a)
	; continue as main rule 
	( [         mbjr ] OCT1 OCT21 dVoct21 = c c)
	( [         mbjr ] OCT1 OCT22 dVoct22 = c c)
	( [         mbjr ] # = c c o)
	( [         mbjr ] = c c a)
	( [         mbjr ] OCT1 OCT21 dVoct21 = c ch)
	( [         mbjr ] OCT1 OCT22 dVoct22 = c ch)
	( [         mbjr ] # = c ch o)
	( [         mbjr ] = c ch a)
	( [         mbjr ] OCT1 OCT21 dVoct21 = j j)
	( [         mbjr ] OCT1 OCT22 dVoct22 = j j)
	( [         mbjr ] # = j j o)
	( [         mbjr ] = j j a)
	( [         mbjr ] OCT1 OCT21 dVoct21 = j jh)
	( [         mbjr ] OCT1 OCT22 dVoct22 = j jh)
	( [         mbjr ] # = j jh o)
	( [         mbjr ] = j jh a)
	;( [         mbjr ] OCT1 OCT21 dVoct21 =  )
	;( [         mbjr ] OCT1 OCT22 dVoct22 =  )
	;( [         mbjr ] # =   o)
	;( [         mbjr ] =   a)
	; continue: ma become same after t, so its only for ba () and ja () and ra ()
	( [          ] OCT1 OCT21 dVoct21 = t t)
	( [          ] OCT1 OCT22 dVoct22 = t t)
	( [          ] # = t t o)
	( [          ] = t t a)
	( [          ] OCT1 OCT21 dVoct21 = t t)
	( [          ] OCT1 OCT22 dVoct22 = t t)
	( [          ] # = t t o)
	( [          ] = t t a)
	( [          ] OCT1 OCT21 dVoct21 = t t)
	( [          ] OCT1 OCT22 dVoct22 = t t)
	( [          ] # = t t o)
	( [          ] = t t a)
	; continue as main rule 
	( [         mbjr ] OCT1 OCT21 dVoct21 = t th)
	( [         mbjr ] OCT1 OCT22 dVoct22 = t th)
	( [         mbjr ] # = t th o)
	( [         mbjr ] = t th a)
	( [         mbjr ] OCT1 OCT21 dVoct21 = d d)
	( [         mbjr ] OCT1 OCT22 dVoct22 = d d)
	( [         mbjr ] # = d d o)
	( [         mbjr ] = d d a)
	( [         mbjr ] OCT1 OCT21 dVoct21 = d dh)
	( [         mbjr ] OCT1 OCT22 dVoct22 = d dh)
	( [         mbjr ] # = d dh o)
	( [         mbjr ] = d dh a)
	; continue: ma become same after n, so its only for ba () and ja () and ra ()
	( [          ] OCT1 OCT21 dVoct21 = n n)
	( [          ] OCT1 OCT22 dVoct22 = n n)
	( [          ] # = n n o)
	( [          ] = n n a)
	( [          ] OCT1 OCT21 dVoct21 = n n)
	( [          ] OCT1 OCT22 dVoct22 = n n)
	( [          ] # = n n o)
	( [          ] = n n a)
	( [          ] OCT1 OCT21 dVoct21 = n n)
	( [          ] OCT1 OCT22 dVoct22 = n n)
	( [          ] # = n n o)
	( [          ] = n n a)
	; continue as main rule 
	( [         mbjr ] OCT1 OCT21 dVoct21 = ta ta)
	( [         mbjr ] OCT1 OCT22 dVoct22 = ta ta)
	( [         mbjr ] # = ta ta o)
	( [         mbjr ] = ta ta a)
	( [         mbjr ] OCT1 OCT21 dVoct21 = ta tah)
	( [         mbjr ] OCT1 OCT22 dVoct22 = ta tah)
	( [         mbjr ] # = ta tah o)
	( [         mbjr ] = ta tah a)
	( [         mbjr ] OCT1 OCT21 dVoct21 = da da)
	( [         mbjr ] OCT1 OCT22 dVoct22 = da da)
	( [         mbjr ] # = da da o)
	( [         mbjr ] = da da a)
	( [         mbjr ] OCT1 OCT21 dVoct21 = da dah)
	( [         mbjr ] OCT1 OCT22 dVoct22 = da dah)
	( [         mbjr ] # = da dah o)
	( [         mbjr ] = da dah a)
	; continue: ma become same after n, so its only for ba () and ja () and ra ()
	( [          ] OCT1 OCT21 dVoct21 = n n)
	( [          ] OCT1 OCT22 dVoct22 = n n)
	( [          ] # = n n o)
	( [          ] = n n a)
	( [          ] OCT1 OCT21 dVoct21 = n n)
	( [          ] OCT1 OCT22 dVoct22 = n n)
	( [          ] # = n n o)
	( [          ] = n n a)
	( [          ] OCT1 OCT21 dVoct21 = n n)
	( [          ] OCT1 OCT22 dVoct22 = n n)
	( [          ] # = n n o)
	( [          ] = n n a)
	; continue as main rule 
	( [         mbjr ] OCT1 OCT21 dVoct21 = p p)
	( [         mbjr ] OCT1 OCT22 dVoct22 = p p)
	( [         mbjr ] # = p p o)
	( [         mbjr ] = p p a)
	( [         mbjr ] OCT1 OCT21 dVoct21 = p ph)
	( [         mbjr ] OCT1 OCT22 dVoct22 = p ph)
	( [         mbjr ] # = p ph o)
	( [         mbjr ] = p ph a)
	; ba has only rule ja fala () and ra fala ()
	( [          ] OCT1 OCT21 dVoct21 = b b)
	( [          ] OCT1 OCT22 dVoct22 = b b)
	( [          ] # = b b o)
	( [          ] = b b a)
	( [          ] OCT1 OCT21 dVoct21 = b b)
	( [          ] OCT1 OCT22 dVoct22 = b b)
	( [          ] # = b b o)
	( [          ] = b b a)
	; continue as main rule 
	( [         mbjr ] OCT1 OCT21 dVoct21 = b bh)
	( [         mbjr ] OCT1 OCT22 dVoct22 = b bh)
	( [         mbjr ] # = b bh o)
	( [         mbjr ] = b bh a)
	; continue: ba and ma both become smae after ma, so ignoring this 
	       ;but ja fala and ra fala() have rule 
	( [          ] OCT1 OCT21 dVoct21 = m m)
	( [          ] OCT1 OCT22 dVoct22 = m m)
	( [          ] # = m m o)
	( [          ] = m m a)
	( [          ] OCT1 OCT21 dVoct21 = m m)
	( [          ] OCT1 OCT22 dVoct22 = m m)
	( [          ] # = m m o)
	( [          ] = m m a)
	; continue as main rule 
	( [         mbjr ] OCT1 OCT21 dVoct21 = j j)
	( [         mbjr ] OCT1 OCT22 dVoct22 = j j)
	( [         mbjr ] # = j j o)
	( [         mbjr ] = j j a)
	; continue: ra becme ref here..
	;( [         mb ] OCT1 OCT21 dVoct21 = r r)
	;( [         mb ] OCT1 OCT22 dVoct22 = r r)
	;( [         mb ] # = r r o)
	;( [         mb ] = r r a)
	; continue: ma become same after n, so its only for ba () and ja () and ra ()
	( [          ] OCT1 OCT21 dVoct21 = l l)
	( [          ] OCT1 OCT22 dVoct22 = l l)
	( [          ] # = l l o)
	( [          ] = l l a)
	( [          ] OCT1 OCT21 dVoct21 = l l)
	( [          ] OCT1 OCT22 dVoct22 = l l)
	( [          ] # = l l o)
	( [          ] = l l a)
	( [          ] OCT1 OCT21 dVoct21 = l l)
	( [          ] OCT1 OCT22 dVoct22 = l l)
	( [          ] # = l l o)
	( [          ] = l l a)
	; continue as main rule 
	( [         mbjr ] OCT1 OCT21 dVoct21 = sh sh)
	( [         mbjr ] OCT1 OCT22 dVoct22 = sh sh)
	( [         mbjr ] # = sh sh o)
	( [         mbjr ] = sh sh a)
	( [         mbjr ] OCT1 OCT21 dVoct21 = sh sh)
	( [         mbjr ] OCT1 OCT22 dVoct22 = sh sh)
	( [         mbjr ] # = sh sh o)
	( [         mbjr ] = sh sh a)
	( [         mbjr ] OCT1 OCT21 dVoct21 = sh sh)
	( [         mbjr ] OCT1 OCT22 dVoct22 = sh sh)
	( [         mbjr ] # = sh sh o)
	( [         mbjr ] = sh sh a)
	( [         mbjr ] OCT1 OCT21 dVoct21 = h h)
	( [         mbjr ] OCT1 OCT22 dVoct22 = h h)
	( [         mbjr ] # = h h o)
	( [         mbjr ] = h h a)
	( [         mbjr ] OCT1 OCT21 dVoct21 = ra ra)
	( [         mbjr ] OCT1 OCT22 dVoct22 = ra ra)
	( [         mbjr ] # = ra ra o)
	( [         mbjr ] = ra ra a)
	( [         mbjr ] OCT1 OCT21 dVoct21 = ra ra)
	( [         mbjr ] OCT1 OCT22 dVoct22 = ra ra)
	( [         mbjr ] # = ra ra o)
	( [         mbjr ] = ra ra a)
	;( [         mbjr ] OCT1 OCT21 dVoct21 = y y)
	;( [         mbjr ] OCT1 OCT22 dVoct22 = y y)
	;( [         mbjr ] # = y y o)
	;( [         mbjr ] = y y a)
	;-------- end ----------- Consonant (single also compaund) --------------------------------
	   
	   
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	;;
	;;			basic character
	;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	;depandant vowel with Candrabindu
	([       ] = aa~)	;U+09be Bengali Vowel Sign Aa
	([       ] = i~)	;U+09bf Bengali Vowel Sign I
	([       ] = i~)	;U+09c0 Bengali Vowel Sign Ii
	([       ] = u~)	;U+09c1 Bengali Vowel Sign U
	([       ] = u~)	;U+09c2 Bengali Vowel Sign Uu
	([       ] = r i~)	;U+09c3 Bengali Vowel Sign Vocalic R
	;([ ]=)	;U+09c4 Bengali Vowel Sign Vocalic Rr
	([       ] = e~)	;U+09c7 Bengali Vowel Sign e
	([       ] = oi~)	;U+09c8 Bengali Vowel Sign oi
	([       ] = o~)	;U+09cb Bengali Vowel Sign O
	( [        ] = ou~)	;U+09cc Bengali Vowel Sign Au
	
	
	;depandant vowel
	( [    ] = aa)	;U+09be Bengali Vowel Sign Aa
	( [    ] = i)	;U+09bf Bengali Vowel Sign I
	( [    ] = i)	;U+09c0 Bengali Vowel Sign Ii
	( [    ] = u)	;U+09c1 Bengali Vowel Sign U
	( [    ] = u)	;U+09c2 Bengali Vowel Sign Uu
	( [    ] = r i)	;U+09c3 Bengali Vowel Sign Vocalic R
	;( [ ]=)	;U+09c4 Bengali Vowel Sign Vocalic Rr
	( [    ] = e)	;U+09c7 Bengali Vowel Sign e
	( [    ] = oi)	;U+09c8 Bengali Vowel Sign oi
	( [    ] = o)	;U+09cb Bengali Vowel Sign O
	( [     ] = ou)	;U+09cc Bengali Vowel Sign Au
	
		
	
	;( [    ] = ~ ) 	; U+0981 Bengali Sign Candrabindu
	( [    ] = ng )	; U+0982 Bengali Sign Anusvara
	( [    ] = )	; U+0983 Bengali Sign Bishorgo
	;vowel
	( [    ] = a ) 	; U+0985  Bengali Letter A
 	( [    ] = aa ) 	; U+0986  Bengali Letter Aa
	( [    ] = i ) 	; U+0987  Bengali Letter I
	( [    ] = i ) 	; U+0988  Bengali Letter Ii
	( [    ] = u ) 	; U+0989  Bengali Letter U
	( [    ] = u ) 	; U+098a  Bengali Letter Uu
	( [    ] = r i ) 	; U+098b  Bengali Letter Vocalic R
	( [    ] = l i ) 		; U+098c  Bengali Letter Vocalic L
	( [    ] = e ) 	; U+098f  Bengali Letter E
	( [    ] = oi ) 	; U+0990  Bengali Letter Ai
	( [    ] = o ) 	; U+0993  Bengali Letter O
	( [    ] = ou ) 	; U+0994  Bengali Letter Au
	
	
	;;consonent followed by vowel
	( [    ] OCT1 OCT21 dVoct21 = k ) 	; U+0995  Bengali Letter Ka
	( [    ] OCT1 OCT22 dVoct22  = k ) 	; U+0995  Bengali Letter Ka
	( [    ] OCT1 OCT21 dVoct21 = kh ) 	; U+0996  Bengali Letter Kha
	( [    ] OCT1 OCT22 dVoct22  = kh ) 	; U+0996  Bengali Letter Kha
	( [    ] OCT1 OCT21 dVoct21 = g ) 	; U+0997  Bengali Letter Ga
	( [    ] OCT1 OCT22 dVoct22  = g ) 	; U+0997  Bengali Letter Ga
	( [    ] OCT1 OCT21 dVoct21 = gh ) 	; U+0998  Bengali Letter Gha
	( [    ] OCT1 OCT22 dVoct22  = gh ) 	; U+0998  Bengali Letter Gha
	( [    ] OCT1 OCT21 dVoct21 = ng ) 	; U+0999  Bengali Letter Nga
	( [    ] OCT1 OCT22 dVoct22  = ng ) 	; U+0999  Bengali Letter Nga
	( [    ] OCT1 OCT21 dVoct21 = c ) 	; U+099a  Bengali Letter Ca
	( [    ] OCT1 OCT22 dVoct22  = c ) 	; U+099a  Bengali Letter Ca
	( [    ] OCT1 OCT21 dVoct21 = ch ) 	; U+099b  Bengali Letter Cha
	( [    ] OCT1 OCT22 dVoct22  = ch ) 	; U+099b  Bengali Letter Cha
	( [    ] OCT1 OCT21 dVoct21 = j ) 	; U+099c  Bengali Letter Ja
	( [    ] OCT1 OCT22 dVoct22  = j ) 	; U+099c  Bengali Letter Ja
	( [    ] OCT1 OCT21 dVoct21 = jh ) 	; U+099d  Bengali Letter Jha
	( [    ] OCT1 OCT22 dVoct22  = jh ) 	; U+099d  Bengali Letter Jha
	;( [    ] OCT1 OCT21 dVoct21 =  ) 	; U+099e  Bengali Letter Nya
	;( [    ] OCT1 OCT22 dVoct22  =  ) 	; U+099e  Bengali Letter Nya
	( [    ] OCT1 OCT21 dVoct21 = t ) 	; U+099f  Bengali Letter Tta
	( [    ] OCT1 OCT22 dVoct22  = t ) 	; U+099f  Bengali Letter Tta
	( [    ] OCT1 OCT21 dVoct21 = th ) 	; U+09a0  Bengali Letter Ttha
	( [    ] OCT1 OCT22 dVoct22  = th ) 	; U+09a0  Bengali Letter Ttha
	( [    ] OCT1 OCT21 dVoct21 = d ) 	; U+09a1  Bengali Letter Dda
	( [    ] OCT1 OCT22 dVoct22  = d ) 	; U+09a1  Bengali Letter Dda
	( [    ] OCT1 OCT21 dVoct21 = dh ) 	; U+09a2  Bengali Letter Ddha
	( [    ] OCT1 OCT22 dVoct22  = dh ) 	; U+09a2  Bengali Letter Ddha
	( [    ] OCT1 OCT21 dVoct21 = n ) 	; U+09a3  Bengali Letter Nna
	( [    ] OCT1 OCT22 dVoct22  = n ) 	; U+09a3  Bengali Letter Nna
	( [    ] OCT1 OCT21 dVoct21 = ta ) 	; U+09a4  Bengali Letter Ta
	( [    ] OCT1 OCT22 dVoct22  = ta ) 	; U+09a4  Bengali Letter Ta
	( [    ] OCT1 OCT21 dVoct21 = tah ) 	; U+09a5  Bengali Letter Tha
	( [    ] OCT1 OCT22 dVoct22  = tah ) 	; U+09a5  Bengali Letter Tha
	( [    ] OCT1 OCT21 dVoct21 = da ) 	; U+09a6  Bengali Letter Da
	( [    ] OCT1 OCT22 dVoct22  = da ) 	; U+09a6  Bengali Letter Da
	( [    ] OCT1 OCT21 dVoct21 = dah ) 	; U+09a7  Bengali Letter Dha
	( [    ] OCT1 OCT22 dVoct22  = dah ) 	; U+09a7  Bengali Letter Dha
	( [    ] OCT1 OCT21 dVoct21 = n ) 	; U+09a8  Bengali Letter Na
	( [    ] OCT1 OCT22 dVoct22  = n ) 	; U+09a8  Bengali Letter Na
	( [    ] OCT1 OCT21 dVoct21 = p ) 	; U+09aa  Bengali Letter Pa
	( [    ] OCT1 OCT22 dVoct22  = p ) 	; U+09aa  Bengali Letter Pa
	( [    ] OCT1 OCT21 dVoct21 = ph ) 	; U+09ab  Bengali Letter Pha
	( [    ] OCT1 OCT22 dVoct22  = ph ) 	; U+09ab  Bengali Letter Pha
	( [    ] OCT1 OCT21 dVoct21 = b ) 	; U+09ac  Bengali Letter Ba
	( [    ] OCT1 OCT22 dVoct22  = b ) 	; U+09ac  Bengali Letter Ba
	( [    ] OCT1 OCT21 dVoct21 = bh ) 	; U+09ad  Bengali Letter Bha
	( [    ] OCT1 OCT22 dVoct22  = bh ) 	; U+09ad  Bengali Letter Bha
	( [    ] OCT1 OCT21 dVoct21 = m ) 	; U+09ae  Bengali Letter Ma
	( [    ] OCT1 OCT22 dVoct22  = m ) 	; U+09ae  Bengali Letter Ma
	( [    ] OCT1 OCT21 dVoct21 = j ) 	; U+09af  Bengali Letter Ya
	( [    ] OCT1 OCT22 dVoct22  = j ) 	; U+09af  Bengali Letter Ya
	( [    ] OCT1 OCT21 dVoct21 = r ) 	; U+09b0  Bengali Letter Ra
	( [    ] OCT1 OCT22 dVoct22  = r ) 	; U+09b0  Bengali Letter Ra
	( [    ] OCT1 OCT21 dVoct21 = l ) 	; U+09b2  Bengali Letter La
	( [    ] OCT1 OCT22 dVoct22  = l ) 	; U+09b2  Bengali Letter La
	( [    ] OCT1 OCT21 dVoct21 = sh ) 	; U+09b6  Bengali Letter Sa
	( [    ] OCT1 OCT22 dVoct22 = sh ) 	; U+09b6  Bengali Letter Sa
	( [    ] OCT1 OCT21 dVoct21 = sh ) 	; U+09b7  Bengali Letter Sa
	( [    ] OCT1 OCT22 dVoct22 = sh ) 	; U+09b7  Bengali Letter Sa
	( [    ] OCT1 OCT21 dVoct21 = sh ) 	; U+09b8  Bengali Letter Sa
	( [    ] OCT1 OCT22 dVoct22 = sh ) 	; U+09b8  Bengali Letter Sa
	( [    ] OCT1 OCT21 dVoct21 = h )	; U+09b9 Bengali Letter Ha
	( [    ] OCT1 OCT22 dVoct22  = h )	; U+09b9 Bengali Letter Ha
	( [    ] OCT1 OCT21 dVoct21 = ra ) 	; U+09dc  Bengali Letter Ra
	( [    ] OCT1 OCT22 dVoct22 = ra ) 	; U+09dc  Bengali Letter Ra
	( [    ] OCT1 OCT21 dVoct21 = ra ) 	; U+09dd  Bengali Letter Ra
	( [    ] OCT1 OCT22 dVoct22 = ra ) 	; U+09dd  Bengali Letter Ra
	( [    ] OCT1 OCT21 dVoct21 = y ) 	; U+09df  Bengali Letter Ya
	( [    ] OCT1 OCT22 dVoct22 = y ) 	; U+09df  Bengali Letter Ya
	
	       ;;consonent followed by hasanta
	( [    ]    = k ) 	; U+0995  Bengali Letter Ka
	( [    ]    = kh ) 	; U+0996  Bengali Letter Kha
	( [    ]    = g ) 	; U+0997  Bengali Letter Ga
	( [    ]    = gh ) 	; U+0998  Bengali Letter Gha
	( [    ]    = ng ) 	; U+0999  Bengali Letter Nga
	( [    ]    = c ) 	; U+099a  Bengali Letter Ca
	( [    ]    = ch ) 	; U+099b  Bengali Letter Cha
	( [    ]    = j ) 	; U+099c  Bengali Letter Ja
	( [    ]    = jh ) 	; U+099d  Bengali Letter Jha
	( [    ]    = ) 	; U+099e  Bengali Letter Nya
	( [    ]    = t ) 	; U+099f  Bengali Letter Tta
	( [    ]    = th ) 	; U+09a0  Bengali Letter Ttha
	( [    ]    = d ) 	; U+09a1  Bengali Letter Dda
	( [    ]    = dh ) 	; U+09a2  Bengali Letter Ddha
	( [    ]    = n ) 	; U+09a3  Bengali Letter Nna
	( [    ]    = ta ) 	; U+09a4  Bengali Letter Ta
	( [    ]    = tah ) 	; U+09a5  Bengali Letter Tha
	( [    ]    = da ) 	; U+09a6  Bengali Letter Da
	( [    ]    = dah ) 	; U+09a7  Bengali Letter Dha
	( [    ]    = n ) 	; U+09a8  Bengali Letter Na
	( [    ]    = p ) 	; U+09aa  Bengali Letter Pa
	( [    ]    = ph ) 	; U+09ab  Bengali Letter Pha
	( [    ]    = b ) 	; U+09ac  Bengali Letter Ba
	( [    ]    = bh ) 	; U+09ad  Bengali Letter Bha
	( [    ]    = m ) 	; U+09ae  Bengali Letter Ma
	( [    ]    = j ) 	; U+09af  Bengali Letter Ya
	( [    ]    = r ) 	; U+09b0  Bengali Letter Ra
	( [    ]    = l ) 	; U+09b2  Bengali Letter La
	( [    ]    = sh ) 	; U+09b6  Bengali Letter Sa
	( [    ]    = sh ) 	; U+09b7  Bengali Letter Sa
	( [    ]    = sh ) 	; U+09b8  Bengali Letter Sa
	( [    ]    = h )	; U+09b9 Bengali Letter Ha
	( [    ]    = ra ) 	; U+09dc  Bengali Letter Ra
	( [    ]    = ra ) 	; U+09dd  Bengali Letter Ra
	( [    ]    = y ) 	; U+09df  Bengali Letter Ya
	
	
	;consonent at end
	( [    ]  # = k ) 	; U+0995  Bengali Letter Ka
	( [    ]  # = kh ) 	; U+0996  Bengali Letter Kha
	( [    ]  # = g ) 	; U+0997  Bengali Letter Ga
	( [    ]  # = gh ) 	; U+0998  Bengali Letter Gha
	( [    ]  # = ng ) 	; U+0999  Bengali Letter Nga
	( [    ]  # = c ) 	; U+099a  Bengali Letter Ca
	( [    ]  # = ch ) 	; U+099b  Bengali Letter Cha
	( [    ]  # = j ) 	; U+099c  Bengali Letter Ja
	( [    ]  # = jh ) 	; U+099d  Bengali Letter Jha
	( [    ]  # = ) 	; U+099e  Bengali Letter Nya
	( [    ]  # = t ) 	; U+099f  Bengali Letter Tta
	( [    ]  # = th ) 	; U+09a0  Bengali Letter Ttha
	( [    ]  # = d ) 	; U+09a1  Bengali Letter Dda
	( [    ]  # = dh ) 	; U+09a2  Bengali Letter Ddha
	( [    ]  # = n ) 	; U+09a3  Bengali Letter Nna
	( [    ]  # = ta ) 	; U+09a4  Bengali Letter Ta
	( [    ]  # = tah ) 	; U+09a5  Bengali Letter Tha
	( [    ]  # = da ) 	; U+09a6  Bengali Letter Da
	( [    ]  # = dah ) 	; U+09a7  Bengali Letter Dha
	( [    ]  # = n ) 	; U+09a8  Bengali Letter Na
	( [    ]  # = p ) 	; U+09aa  Bengali Letter Pa
	( [    ]  # = ph ) 	; U+09ab  Bengali Letter Pha
	( [    ]  # = b ) 	; U+09ac  Bengali Letter Ba
	( [    ]  # = bh ) 	; U+09ad  Bengali Letter Bha
	( [    ]  # = m ) 	; U+09ae  Bengali Letter Ma
	( [    ]  # = j ) 	; U+09af  Bengali Letter Ya
	( [    ]  # = r ) 	; U+09b0  Bengali Letter Ra
	( [    ]  # = l ) 	; U+09b2  Bengali Letter La
	( [    ] # = sh ) 	; U+09b6  Bengali Letter Sa
	( [    ] # = sh ) 	; U+09b7  Bengali Letter Sa
	( [    ] # = sh ) 	; U+09b8  Bengali Letter Sa
	( [    ] # = h )	; U+09b9 Bengali Letter Ha
	( [    ] # = ra ) 	; U+09dc  Bengali Letter Ra
	( [    ] # = ra ) 	; U+09dd  Bengali Letter Ra
	( [    ] # = y ) 	; U+09df  Bengali Letter Ya
	
	;;consonent with Candrabindu
	( [       ] = k a~ ) 	; U+0995  Bengali Letter Ka
	( [       ] = kh a~ ) 	; U+0996  Bengali Letter Kha
	( [       ] = g a~ ) 	; U+0997  Bengali Letter Ga
	( [       ] = gh a~ ) 	; U+0998  Bengali Letter Gha
	( [       ] = ng a~ ) 	; U+0999  Bengali Letter Nga
	( [       ] = c a~ ) 	; U+099a  Bengali Letter Ca
	( [       ] = ch a~ ) 	; U+099b  Bengali Letter Cha
	( [       ] = j a~ ) 	; U+099c  Bengali Letter Ja
	( [       ] = jh a~ ) 	; U+099d  Bengali Letter Jha
	;( [       ] =  a~ ) 	; U+099e  Bengali Letter Nya
	( [       ] = t a~ ) 	; U+099f  Bengali Letter Tta
	( [      ] = th a~ ) 	; U+09a0  Bengali Letter Ttha
	( [       ] = d a~ ) 	; U+09a1  Bengali Letter Dda
	( [       ] = dh a~ ) 	; U+09a2  Bengali Letter Ddha
	( [       ] = n a~ ) 	; U+09a3  Bengali Letter Nna
	( [       ] = ta a~ ) 	; U+09a4  Bengali Letter Ta
	( [       ] = tah a~ ) 	; U+09a5  Bengali Letter Tha
	( [       ] = da a~ ) 	; U+09a6  Bengali Letter Da
	( [       ] = dah a~ ) 	; U+09a7  Bengali Letter Dha
	( [       ] = n a~ ) 	; U+09a8  Bengali Letter Na
	( [       ] = p a~ ) 	; U+09aa  Bengali Letter Pa
	( [       ] = ph a~ ) 	; U+09ab  Bengali Letter Pha
	( [       ] = b a~ ) 	; U+09ac  Bengali Letter Ba
	( [       ] = bh a~ ) 	; U+09ad  Bengali Letter Bha
	( [       ] = m a~ ) 	; U+09ae  Bengali Letter Ma
	( [       ] = j a~ ) 	; U+09af  Bengali Letter Ya
	( [       ] = r a~ ) 	; U+09b0  Bengali Letter Ra
	( [       ] = l a~ ) 	; U+09b2  Bengali Letter La
	( [       ] = sh a~ ) 	; U+09b6  Bengali Letter Sa
	( [       ] = sh a~ ) 	; U+09b7  Bengali Letter Sa
	( [       ] = sh a~ ) 	; U+09b8  Bengali Letter Sa
	( [       ] = h a~ ) 	; U+09b9 Bengali Letter Ha
	( [       ] = ra a~ ) 	; U+09dc  Bengali Letter Ra
	( [       ] = ra a~ ) 	; U+09dd  Bengali Letter Ra
	( [       ] = y a~ ) 	; U+09df  Bengali Letter Ya
	
	;consonent at middle
	( [    ] = k a ) 	; U+0995  Bengali Letter Ka
	( [    ] = kh a ) 	; U+0996  Bengali Letter Kha
	( [    ] = g a) 	; U+0997  Bengali Letter Ga
	( [    ] = gh a ) 	; U+0998  Bengali Letter Gha
	( [    ] = ng a ) 	; U+0999  Bengali Letter Nga
	( [    ] = c a ) 	; U+099a  Bengali Letter Ca
	( [    ] = ch a ) 	; U+099b  Bengali Letter Cha
	( [    ] = j a ) 	; U+099c  Bengali Letter Ja
	( [    ] = jh a ) 	; U+099d  Bengali Letter Jha
	( [    ] = ) 	; U+099e  Bengali Letter Nya
	( [    ] = t a ) 	; U+099f  Bengali Letter Tta
	( [    ] = th a ) 	; U+09a0  Bengali Letter Ttha
	( [    ] = d a ) 	; U+09a1  Bengali Letter Dda
	( [    ] = dh a ) 	; U+09a2  Bengali Letter Ddha
	( [    ] = n a ) 	; U+09a3  Bengali Letter Nna
	( [    ] = ta a ) 	; U+09a4  Bengali Letter Ta
	( [    ] = tah a ) 	; U+09a5  Bengali Letter Tha
	( [    ] = da a ) 	; U+09a6  Bengali Letter Da
	( [    ] = dah a ) 	; U+09a7  Bengali Letter Dha
	( [    ] = n a ) 	; U+09a8  Bengali Letter Na
	( [    ] = p a ) 	; U+09aa  Bengali Letter Pa
	( [    ] = ph a ) 	; U+09ab  Bengali Letter Pha
	( [    ] = b a ) 	; U+09ac  Bengali Letter Ba
	( [    ] = bh a ) 	; U+09ad  Bengali Letter Bha
	( [    ] = m a ) 	; U+09ae  Bengali Letter Ma
	( [    ] = j a ) 	; U+09af  Bengali Letter Ya
	( [    ] = r a ) 	; U+09b0  Bengali Letter Ra
	( [    ] = l a ) 	; U+09b2  Bengali Letter La
	( [    ] = sh a ) 	; U+09b6  Bengali Letter Sa
	( [    ] = sh a ) 	; U+09b7  Bengali Letter Sa
	( [    ] = sh a ) 	; U+09b8  Bengali Letter Sa
	( [    ] = h a )	; U+09b9 Bengali Letter Ha	
	( [    ] = ra a ) 	; U+09dc  Bengali Letter Ra
	( [    ] = ra a ) 	; U+09dd  Bengali Letter Ra
	( [    ] = y a ) 	; U+09df  Bengali Letter Ya
	
	( [    ] = ta ) 	; U+09ce  Bengali Letter ta
	;hasanta
	( [    ] = )
	( [    ] = )
	( [    ] = )
  );end start rules
);end lts.ruleset

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Postlexical Rules 
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define (crblp_bnBD::postlex_rule1 utt)
  "(crblp_bnBD::postlex_rule1 utt)
A postlexical rule form correcting phenomena over word boundaries."
  (mapcar
   (lambda (s)
     ;; do something
     )
   (utt.relation.items utt 'Segment))
   utt)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Lexicon definition
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(lex.create "crblp_bnBD")
(lex.set.phoneset "crblp_bnBD")

(if (probe_file (path-append crblp_bnBD_alg_dir "festvox/crblp_bnBD_lex.out"))
    (lex.set.compile.file (path-append crblp_bnBD_alg_dir "festvox/crblp_bnBD_lex.out"))
    )

(lex.set.lts.method 'crblp_bnBD_lts_function)
    
(crblp_bnBD_addenda)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; Lexicon setup
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define (crblp_bnBD_alg::select_lexicon)
  "(crblp_bnBD_alg::select_lexicon)
Set up the lexicon for crblp_bnBD."
  (lex.select "crblp_bnBD")

  ;; Post lexical rules
  (set! postlex_rules_hooks (list crblp_bnBD::postlex_rule1))
)

(define (crblp_bnBD_alg::reset_lexicon)
  "(crblp_bnBD_alg::reset_lexicon)
Reset lexicon information."
  t
)

(provide 'crblp_bnBD_alg_lexicon)

