;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;                                                                     ;;;
;;;                     Carnegie Mellon University                      ;;;
;;;                  and Alan W Black and Kevin Lenzo                   ;;;
;;;                      Copyright (c) 1998-2000                        ;;;
;;;                        All Rights Reserved.                         ;;;
;;;                                                                     ;;;
;;; Permission is hereby granted, free of charge, to use and distribute ;;;
;;; this software and its documentation without restriction, including  ;;;
;;; without limitation the rights to use, copy, modify, merge, publish, ;;;
;;; distribute, sublicense, and/or sell copies of this work, and to     ;;;
;;; permit persons to whom this work is furnished to do so, subject to  ;;;
;;; the following conditions:                                           ;;;
;;;  1. The code must retain the above copyright notice, this list of   ;;;
;;;     conditions and the following disclaimer.                        ;;;
;;;  2. Any modifications must be clearly marked as such.               ;;;
;;;  3. Original authors' names are not deleted.                        ;;;
;;;  4. The authors' names are not used to endorse or promote products  ;;;
;;;     derived from this software without specific prior written       ;;;
;;;     permission.                                                     ;;;
;;;                                                                     ;;;
;;; CARNEGIE MELLON UNIVERSITY AND THE CONTRIBUTORS TO THIS WORK        ;;;
;;; DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING     ;;;
;;; ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT  ;;;
;;; SHALL CARNEGIE MELLON UNIVERSITY NOR THE CONTRIBUTORS BE LIABLE     ;;;
;;; FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES   ;;;
;;; WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN  ;;;
;;; AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,         ;;;
;;; ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF      ;;;
;;; THIS SOFTWARE.                                                      ;;;
;;;                                                                     ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;							modified by murtoza
;;;							               2008
;;; Tokenizer for bnBD
;;;
;;;  To share this among voices you need to promote this file to
;;;  to say festival/lib/crblp_bnBD/ so others can use it.
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;; Load any other required files

;; Punctuation for the particular language
(set! crblp_bnBD_alg::token.punctuation "\"'`.,:;!?(){}[]")
(set! crblp_bnBD_alg::token.prepunctuation "\"'`({[")          ;"
(set! crblp_bnBD_alg::token.whitespace " \t\n\r")
(set! crblp_bnBD_alg::token.singlecharsymbols "")

;;; Voice/bnBD token_to_word rules 
(define (crblp_bnBD_alg::token_to_words token name)
  "(crblp_bnBD_alg::token_to_words token name)
Specific token to word rules for the voice crblp_bnBD_alg.  Returns a list
of words that expand given token with name."
  
  ;(print "i m in tokenizer")
  ;(print "name: ") (print name)
  ;(print "token: ") (print token)

  (if (string-matches name "[0-9]+")
    ;reading as english digit one by one
    (begin
      (list (set! name (replace_matched name english_basic_number_table)))
      ;(print name)
    )
  );end of if
  (if (string-matches name "[a-z]+")
    ;reading as english char one by one
     (begin
       (set! name (replace_matched name english_basic_char_table))
       ;(print name) 
       (list name)
     )
  );end of if

  (set! name (bengali_string_cleanup name))
  ;(print name)
  (let ((number "[0-9,]+\\(\\.[0-9]+\\)?") numDiv)
     ;starting body
     (cond
        ;bangla day (date)
        ((and (or (string-matches name "[1-9]") (string-matches name "[1-2][0-9]") 
                  (string-matches name "30") (string-matches name "31") )
              (or (equal? (item.feat token "n.name") "লা") (equal? (item.feat token "n.name") "রা")
                  (equal? (item.feat token "n.name") "ঠা") (equal? (item.feat token "n.name") "শে")
                  (equal? (item.feat token "n.name") "ই") )
              )
	      (list (set! name (car(bengali_table_lookup name bengali_day_table))))
        )
        ((or (equal? name "লা") (equal? name "রা") (equal? name "ঠা") (equal? name "শে") (equal? name "ই") )
          ;body
          (set! tmp (bengali_string_cleanup (item.feat token "p.name")))
          (if (or (string-matches tmp "[1-9]") 
                  (string-matches tmp "[1-2][0-9]") 
                  (string-matches tmp "30") (string-matches tmp "31"))
              (set! name "")
          );if
           (list name)
        )
        ((or (string-matches name "1লা") (string-matches name "[2-3]রা") (string-matches name "4ঠা")
             (string-matches name "[7-9]ই") (string-matches name "1[0-9]ই")
             (string-matches name "2[0-9]শে") (string-matches name "3[0-1]শে")  
          )
	      (list (set! name (car(bengali_table_lookup name bengali_day_table))))
        )
        ;bangla day (date)
        
        ;taka
        ( (or (string-matches name (string-append number "/-" )) (string-matches name (string-append number "/=" )) )
          ;(print "taka")
          (set! taka1 (string-before name "/="))
          (set! taka2 (string-before name "/-"))
          (if (equal? taka2 "")
              (set! taka taka1)
              (set! taka taka2)
          )
          ;no list
          (set! name (read_bengali_taka_poysha taka))
          (make_list_from_string name )
        );;;
        ( (string-matches name (string-append number "৳" ) )
          ;no list
          (set! taka (string-before name "৳"))
          (set! name (read_bengali_taka_poysha taka))
          (make_list_from_string name )
        );;;
        ( (string-matches name "টাকা") 
            (set! prev (bengali_string_cleanup (item.feat token "p.name")) )
            
            (if (or (string-matches prev (string-append number "/-" )) 
                    (string-matches prev (string-append number "/=" ))
                    (string-matches prev (string-append number "৳" ))
                    (string-matches prev number) )
               (set! name "")
            );if
          (list name)
        );;;
        ( (and (string-matches name number) (string-matches (item.feat token "n.name") "টাকা") )
          ;no list
          (set! name (read_bengali_taka_poysha name))
          (make_list_from_string name )
        );;;
        ;end taka
        
        ;number (time also there)
        ((string-matches name number )
          ;no list
          ;(list (make_list_from_string (crblp_bnBD::number token name) ) )
          (make_list_from_string (crblp_bnBD::number token name) )
	  
          
          ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
          ;(list (set! name (crblp_bnBD::number token name)))
        );end number
	
	;number[+-*/]number
	( (string-matches name (string-append 
	           (string-append number "[\-|\/|\\+|\\*]") number))
	  (set! name (read_bangla_number_with_operator token name))
	  ;no list
	  (make_list_from_string name)
        );end number[+-*/]number
	
	;number:number
	( (string-matches name (string-append 
	           (string-append number ":") number))
	  (set! name (read_colon_operator token name))
	  ;no list
	  (make_list_from_string name)
	);end number:number
	
	;number%
	( (string-matches name (string-append number "%") )
	  ;(set! name (string-append "শতকরা " (crblp_bnBD::number token (string-before name "%"))))
	  ;(list "শতকরা" (crblp_bnBD::number token (string-before name "%")))
	  
	  (set! name (string-append "শতকরা " (crblp_bnBD::number token (string-before name "%"))) )
	  ;no list
	  (make_list_from_string name)
        );end number%
        
	; math op
	((or (equal? name "+") (equal? name "-") (equal? name "*") (equal? name "/"))
	 (list (set! name (read_math_operator name "n")))
	);end math op

        
        ;number-numver- ...
        ((string-matches name "\\([0-9]+\-\\)+[0-9]+")  
          (set! name (read_num_op_num_con name "-"))
          ;no list
	  (make_list_from_string name)
        );end number-numver-...
        ;number/numver/ ...
        ((string-matches name "\\([0-9]+\/\\)+[0-9]+")  
          (set! name (read_num_op_num_con name "/"))
          ;no list
	  (make_list_from_string name)
        );end number/numver/...
        ;number.numver. ...
        ((string-matches name "\\([0-9]+\.\\)+[0-9]+")  
          (set! name (read_num_op_num_con name "."))
          ;no list
	  (make_list_from_string name)
        );end number.numver....
        
        ;bangla ordinal number ১ম, ১১তম ...
        ( (or (string-matches name "[1|5|7|8|9]ম") (string-matches name "[2-3]য়") (string-matches name "4র্থ")
              (string-matches name "6ষ্ঠ") (string-matches name "[1-9][0-9]+তম") (string-matches name "10ম"))
          (set! name (read_bengali_ordinal_num name))
          ;no list
	  (make_list_from_string name)
        );end bangla ordinal number
        	
        (t ;; when no specific rules apply do the general ones
	   ;(list name)  bengali_numbers_table   fail_safe
	   (list (set! name (replace_matched name fail_safe)))
	   ;(print name)
	   ;no list
	   (make_list_from_string name)
	   ;(list (set! name (replace_matched name bengali_numbers_table)))
	   ;(print (string-before name "["))
	);; end no rule
     ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
     );end of cond
  );end of let
  ;(print "out:")(print name)

);end define token_to_words



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define (crblp_bnBD::number token name)
  ;(crblp_bnBD::number token name)
;Return list of words that pronounce this number in bnBD.
  (set! name (remove_coma_from_number name))
  (cond
     ;integer with no zero leading
     ( (string-matches name "[1-9][0-9]*") ;cond
       (set! name (expand_bengali_integer_to_words name))
     );end
          
     ( (string-matches name "[0-9]*\\.[0-9]+") ;cond
       ;body
       (if (and (equal? (item.feat token "n.name") "টা")
         (or (string-matches name "[1-9]\\.[0-5][0-9]") (string-matches name "1[0-2]\\.[0-5][0-9]")) );cond
              
         (set! name (string-append (string-append (expand_bengali_integer_to_words (string-before name ".")) " টা " )
                          (expand_bengali_integer_to_words (string-after name ".") ) )  
           );set
         ;else
         (begin
          (set! name (expand_bengali_floatingpoint_to_words name) )
          ;(expand_bengali_floatingpoint_to_words name)
         );begin
       
     );end of if
     );end 
  );cond
  
  ;(print name)
  ;(print (list (make_list_from_string name)))
  ;(car (make_list_from_string name))
  name
)

(define (read_colon_operator token name)
   
   (let ((out ""))
      ;"\\([0]?[0-9]\\)|\\([1][0-9]\\)|\\([2][0-3]\\):\\([0]?[0-9]\\)|\\([1-5][0-9]\\)"
      (cond 
         ( (and 
            (or (string-matches name "[0]?[0-9]:[1-5][0-9]") (string-matches name "[0]?[0-9]:[0]?[0-9]")
                (string-matches name "[1][0-9]:[1-5][0-9]") (string-matches name "[1][0-9]:[0]?[0-9]")
                (string-matches name "[2][0-3]:[1-5][0-9]") (string-matches name "[2][0-3]:[0]?[0-9]")
            )
            (or (equal? (item.feat token "p.name") "সকাল") (equal? (item.feat token "p.name")"বেলা")
               (equal? (item.feat token "p.name") "দুপুর") (equal? (item.feat token "p.name") "বিকাল")
               (equal? (item.feat token "p.name") "সন্ধা") (equal? (item.feat token "p.name") "রাত")
            );or
           );and
           (set! out (string-append 
                      (string-append (expand_bengali_integer_to_words(string-before name ":")) " টা ")
                      (string-append (expand_bengali_integer_to_words(string-after name ":")) " মিনিট")
                     )
           )
         )
         ( t ;; when no specific rules apply do the general ones
             (set! out (read_bangla_number_with_operator token name)) )
      );cond
      out
   );let
)


(define (read_bengali_taka_poysha name)
  (let (out)
    (cond
      ( (string-matches name "[0-9]*")
         (set! out (string-append (expand_bengali_integer_to_words name) " টাকা"))
      )
      ((string-matches name "[0-9]*\\.[0-9][0-9]")
       (set! out (string-append (string-append (expand_bengali_integer_to_words (string-before name ".")) " টাকা " )
                                (string-append (expand_bengali_integer_to_words (string-after name ".")) " পয়সা")));set
      )
      ((string-matches name "[0-9]*\\.[0-9]+")
       (set! out (string-append (expand_bengali_floatingpoint_to_words name) " টাকা" ));set
      )
    
    );cond
    out
  );let
)

(define (read_bengali_ordinal_num name)
  (let ( out )
    (cond ;"[1|5|7|8|9]ম"
       ((equal? name "1ম")
          (set! out "প্রথম")
       )
       ((equal? name "2য়")
          (set! out "দিতীয়")
       )
       ((equal? name "3য়")
          (set! out "তৃতীয়")
       )
       ((equal? name "4র্থ")
          (set! out "চতুর্থ")
       )
       ((equal? name "5ম") 
         (set! out "পঞ্চম")
       )
       ((equal? name "6ষ্ঠ") 
         (set! out "ছষ্ঠ")
       )
       ((equal? name "7ম")
         (set! out "সপ্তম")
       )
       ((equal? name "8ম") 
         (set! out "অষ্টম")
       )
       ((equal? name "9ম") 
         (set! out "নবম")
       )
       ((equal? name "10ম") 
         (set! out "দশম")
       )
       ((string-matches name "[1-9][0-9]+তম")
        (set! out (string-append (expand_bengali_integer_to_words (string-before name "তম")) "তম"))
       )
    );cond
    out
  );let
)

(define (read_num_op_num_con name op)
   (let ((opLen (count_a_char name op)) (i 0) (out "") )
    ;(print "working now...")
    ;(print op)
    (while (not(equal? i opLen))
      (begin
         (set! fst (string-before name op))
         (set! out (string-append out (expand_bengali_integer_to_words fst)))
         (set! out (string-append out " "))
         (set! name (string-after name op))
         (set! i (+ i 1))
      );begin
    );while
    (set! out (string-append out (expand_bengali_integer_to_words name)))
    (set! out (string-append out " "))
    ;(print out)
   );let
)

(define (read_bangla_number_with_operator token name)
   (let ( (number "[0-9,]+\\(\\.[0-9]+\\)?")
        )
      (set! numDiv (string-append (string-append number "\/") number) )
      (set! numAdd (string-append (string-append number "\\+") number) )
      (set! numSub (string-append (string-append number "\-") number) )
      (set! numMul (string-append (string-append number "\\*") number) )
      (set! numRatio (string-append (string-append number ":") number) )
      
      (cond
	;number/number
	((string-matches name numDiv)
           (set! name (string-append 
                   (string-append (crblp_bnBD::number token (string-before name "/")) (read_math_operator "/" "y") )
                     (crblp_bnBD::number token (string-after name "/") ) ) )
        );end number/number
         
        ;number+number
	((string-matches name numAdd)
           (set! name (string-append 
                   (string-append (crblp_bnBD::number token (string-before name "+")) (read_math_operator "+" "y"))
                     (crblp_bnBD::number token (string-after name "+") ) ) )
        );end number+number
         
        ;number-number
	((string-matches name numSub)
           (set! name (string-append 
                   (string-append (crblp_bnBD::number token (string-before name "-")) (read_math_operator "-" "y"))
                     (crblp_bnBD::number token (string-after name "-") ) ) )
        );end number-number
        
        ;number*number
	((string-matches name numMul)
           (set! name (string-append 
                   (string-append (crblp_bnBD::number token (string-before name "*")) (read_math_operator "*" "y"))
                     (crblp_bnBD::number token (string-after name "*") ) ) )
        );end number*number
        
        ;number:number
	((string-matches name numRatio)
           (set! name (string-append 
                   (string-append (crblp_bnBD::number token (string-before name ":")) (read_math_operator ":" "y"))
                     (crblp_bnBD::number token (string-after name ":") ) ) )
        );end number:number
      );cond
    );let
)

(define (crblp_bnBD_alg::select_tokenizer)
  "(crblp_bnBD_alg::select_tokenizer)
Set up tokenizer for bnBD."
  (Parameter.set 'Language 'crblp_bnBD)
  (set! token.punctuation crblp_bnBD_alg::token.punctuation)
  (set! token.prepunctuation crblp_bnBD_alg::token.prepunctuation)
  (set! token.whitespace crblp_bnBD_alg::token.whitespace)
  (set! token.singlecharsymbols crblp_bnBD_alg::token.singlecharsymbols)

  (set! token_to_words crblp_bnBD_alg::token_to_words)
)

(define (crblp_bnBD_alg::reset_tokenizer)
  "(crblp_bnBD_alg::reset_tokenizer)
Reset any globals modified for this voice.  Called by 
(crblp_bnBD_alg::voice_reset)."
  ;; None

  t
)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(define (count_a_char name cahr)
  (let ( (digit (symbolexplode name)) 
         (count 0) (len (length name)) (i 0) )
    (while (not(equal? i len))
      (begin
         (set! fst (car digit))
         (set! digit (cdr digit))
         (if (string-equal fst cahr)
             (set! count (+ count 1))
         )
         (set! i (+ i 1))
      );begin
    );while
    count
  );let
)

(define (read_math_operator op space)
  (let (out )
    (cond
      ((string-equal op "+")
        (set! out "যোগ") )
      ((string-equal op "-")
        (set! out "বিয়োগ") )
      ((string-equal op "*")
        (set! out "গুণ") )
      ((string-equal op "/")
        (set! out "ভাগ") )
      ((string-equal op ":")
        (set! out "অনুপাত") )
    );cond
    (if (equal? space "y")
        (set! out (string-append(string-append " " out) " "))
    );end of if
    out
  );let
)

(define (bengali_match_string_with_table input_string string_table)
  ;;checks is any of the strings in string_table match a substring of input_string
  ;;returns the matched string from string_table
  (let (substr (matched_substr ""))
    (while (and (not (null? string_table)) (string-equal matched_substr ""))
  	(set! substr (car (car string_table)))
	(set! string_table (cdr string_table))
	(if (or (string-equal substr "$") (string-equal substr "^") (string-equal substr "?")
		(string-equal substr "*") (string-equal substr "+") (string-equal substr "."))
	  	(set! match_string (string-append ".*\\" substr ".*"))
	  	(set! match_string (string-append ".*" substr ".*")))
  	(if (string-matches input_string match_string) (set! matched_substr substr))
    );;end of while
    matched_substr
  );;end of let
)

(define (replace_matched input_string string_table)
    (while (and (set! matched_string 
              (bengali_match_string_with_table input_string string_table))
	      (not (string-equal matched_string "")))
	      
	      ;(print matched_string) 
	      ;(print (string-before input_string matched_string))
  	      ;(car (bengali_table_lookup matched_string string_table))
              ;(print (string-after input_string matched_string))
              
	      
	      (set! input_string (string-append (string-before input_string matched_string)
  	         (car (bengali_table_lookup matched_string string_table))
                 (string-after input_string matched_string))
              )
    );;end of while
    ;(print (string-append input_string " ") )
    input_string
)

(define (remove_coma_from_number number)   
   (let ((tmp number) (out "") (digit (symbolexplode number)) 
      (len (length number)) (i 0) )
   
     (while (not(equal? i len))
      (begin
         (set! fst (car digit))
         (set! digit (cdr digit))
         (if (string-equal fst ",")
             ()
             (set! out (string-append out fst))
         )
         (set! i (+ i 1))
      );begin
     );while
     out
   );end of let 
)

(define (str-split str ch)
  (let ((len (string-length str)))
    (letrec
      ((split
        (lambda (a b)
          (cond
            ((>= b len) (if (= a b) '() (cons (substring str a b) '())))
            ((char=? ch (string-ref str b)) (if (= a b)
                                              (split (+ 1 a) (+ 1 b))
                                              (cons (substring str a b) (split b b))))
            (else (split a (+ 1 b)) )
          );cond
        );lambda
      ));split
      (split 0 0)
    );letrec
  );let
)


(define (ds2ss str)
     (if (string-matches str ".+  .+")
         (string-append 
             (string-before str "  ") " " (ds2ss (string-after str "  ")))  
	 (string-append str "")
    )
)
(define (make_list_from_string str)
  ;(print str)
  ;(print (ds2ss str))
  (make_list_from_string_ str)
  ;(make_list_from_string_ (ds2ss str))
)
(define (make_list_from_string_ str)
     (if (string-matches str ".* .*")
         (cons 
              (string-before str " ") 
              (make_list_from_string_ (string-after str " ")))
	 (list (string-append str ""))
     )
)


(define (count_from_string str what) 
   (let ((count_out 0) (len (length str)) (seg (symbolexplode str)) (i 0))
           
     (while (not(equal? i len))
      (begin
         (set! fst (car seg))
         (set! seg (cdr seg))
         (if (string-equal fst what)
             (set! count_out (+ count_out 1))
         )
         (set! i (+ i 1))
      );begin
     );while
     count_out
   );end of let 
)

(define (bengali_match_string_start_with_list input_string string_list)
  ;;checks is any of the strings in string_list match the start of input_string
  ;;returns the matched string from string_list
  (let (substr (matched_substr ""))
  (while (and (not (null? string_list)) (string-equal matched_substr ""))
  	(set! substr (car string_list))
	(set! string_list (cdr string_list))
	(if (string-equal substr "$") 
	  	(set! match_string (string-append "\\" substr ".*"))
	  	(set! match_string (string-append substr ".*")))
  	(if (string-matches input_string match_string) (set! matched_substr substr)))
  matched_substr
))

(define (bengali_string_cleanup input_string)
  ;;ensures the string has characters with are either in the bengali unicode range,
  ;;ascii punctuation or represent a currency symbol
  (let (curr_char next_char next_next_char (clean_string "") matched_string) 

     ;;convert bengali unicode digits to ascii
     (while (and (set! matched_string 
              (bengali_match_string_with_table input_string bengali_numbers_table))
	      (not (string-equal matched_string "")))
	      
	      ;(print matched_string)
	      (set! input_string (string-append (string-before input_string matched_string)
  	         (car (bengali_table_lookup matched_string bengali_numbers_table)) 
                 (string-after input_string matched_string))
              )
       );;end of while
              
       ( while (not (equal? input_string ""))
	     (set! curr_char (ascii_of (substring input_string 0 1)))
	     (set! next_char (ascii_of (substring input_string 1 1)))
	     (set! next_next_char (ascii_of (substring input_string 2 1)))
	     (cond
      	         ;;basic ascii
	         ((or (or (and (>= curr_char 33) (<= curr_char 64)) 
                          (and (>= curr_char 91) (<= curr_char 96))
                      )                    
		  (and (>= curr_char 123) (<= curr_char 126)))
	          (set! num_chars_valid 1)
                 )
	         ;;bengali unicode block (of the form \340 {\246 \247} [\200 .. \277]) 
	         ((and (equal? curr_char 224)
		       (or (equal? next_char 166) (equal? next_char 167))
		       (and (>= next_next_char 128) (<= next_next_char 191))
                  )
	          (set! num_chars_valid 3)
                 )
	         ;;Supplementary chars like yen, pound, cent, copyright, registered mark, Euro
	         ((not (string-equal (set! matched_string 
		       (bengali_match_string_start_with_list 
                       input_string bengali_supplementary_char_list)) "")
                  )(set! num_chars_valid (string-length matched_string))
                 )
	        ;;does not match anything, throw away the char
	        (t (set! num_chars_valid 0))
    	)
	(set! clean_string (string-append clean_string 
             (substring input_string 0 num_chars_valid))
        )
	;;does not match anything, throw away the char
        (if (equal? num_chars_valid 0) (set! num_chars_valid 1))
	(set! input_string (substring input_string num_chars_valid 
            (- (string-length input_string) num_chars_valid))
        )
     );;end of while
            
    clean_string
  )
)

(define (bengali_two_digit_number_to_words name)
  ;number to words for 0-99
  ;(print(bengali_table_lookup name bengali_two_digit_numbers_table))
  (let (lst units tens) 
    (set! lst (reverse (symbolexplode name)))
    (set! units (car lst))
    (set! tens (car (cdr lst)))

    ;remove leading zero
    (if (or (string-equal tens "0") (eq tens nil) ) 
    	(bengali_table_lookup units bengali_basic_number_table)
      ;else
	(bengali_table_lookup name bengali_two_digit_numbers_table))
  );;end of let
);


( define (expand_bengali_floatingpoint_to_words number)
  (let ( (before (string-before number ".")) (after 
         (string-after number ".")) out )

     (set! out (string-append (expand_bengali_integer_to_words before) " দশমিক "))
     (set! out (string-append out (expand_bengali_number_as_digit after) ) )
     out
     ;(list (expand_bengali_integer_to_words before) "দশমিক" (expand_bengali_number_as_digit after))
     ;(append (expand_bengali_integer_to_words before) '("দশমিক") (expand_bengali_number_as_digit after))
  );let
)

(define (expand_bengali_integer_to_words number)
     (set! digits (reverse(symbolexplode number)))
     (expand_bengali_integer_to_words_ digits)
)
          
(define (expand_bengali_integer_to_words_ digits)
  (let (digit_list out_list len index unit tens out_string zero out_list) 
   ;body
    ;(print 'input:)(print number)
    (set! digit_list digits)
    (set! len (length digit_list))
    (set! zero (car(bengali_two_digit_number_to_words "0")))
    
    (set! index 1)
    (while (<= index len)
      ;body
      (cond
         ((equal? index 1)
           (if (equal? index len)
              (begin
               (set! out_string (car(bengali_two_digit_number_to_words (car digit_list))))
               (set! out_list (list out_string))
               ;(print out_string)
              )
            ;else
              (begin   
               ;(print"1st digit")
               (set! tens (car digit_list))
               ;(print tens)
               (set! digit_list (cdr digit_list))
               ;(print digit_list)
              );end of begin
           );;end of if
         );; index 1
         ( (equal? index 2)
           (begin
             ;(print "index = 2")
             (set! tens (string-append (car digit_list) tens))
             ;(print tens)
             (set! digit_list (cdr digit_list))
             (set! tmp (car (bengali_two_digit_number_to_words tens)))
             (if (string-equal zero tmp)
        	(set! out_string "")
        	(set! out_string tmp)
        	(set! out_list (list out_string))
	    )
           );end of begin
         );index 2
         ((equal? index 3) 
            (set! thisDigit (car digit_list) )
            ;(print "index = 3")
            ;(print thisDigit)
            (set! digit_list (cdr digit_list))
            (set! tmp (car(bengali_two_digit_number_to_words thisDigit)))
            (set! soto (string-append tmp " শত ") )
            (if (string-equal zero tmp)
        	()
        	(set! out_string (string-append soto out_string))
        	(set! out_list (list out_list out_string))
	    )
         );index = 3
         ((equal? index 4) 
            (set! thisDigit (car digit_list) )
            ;(print "index = 4")
            ;(print thisDigit)
            (set! digit_list (cdr digit_list))
            
            (if (equal? index len)
               (begin 
        	  (set! tmp (car(bengali_two_digit_number_to_words thisDigit)))
        	  (set! hajar (string-append tmp " হাজার ") )
        	  (if (string-equal zero tmp)
        	      ()
        	      (set! out_string  (string-append hajar out_string))
        	      (set! out_list (list out_list out_string))
	          )
               );end begin
             ;else
               (begin
                  (set! tens thisDigit)
               )
            )
         );index = 4
         ((equal? index 5)
            (set! thisDigit (car digit_list) )
            ;(print "index = 5")
            ;(print thisDigit)
            (set! digit_list (cdr digit_list))
            
            (set! tens (string-append thisDigit tens))
            ;(print tens)
            (set! tmp (car(bengali_two_digit_number_to_words tens)))
       	    (set! hajar (string-append tmp " হাজার ") )
       	    (if (string-equal zero tmp)
        	()
        	(set! out_string  (string-append hajar out_string))
        	(set! out_list (list out_list out_string))
	    )
         );index = 5
         ((equal? index 6) 
            (set! thisDigit (car digit_list) )
            ;(print "index = 6")
            ;(print thisDigit)
            (set! digit_list (cdr digit_list))
            
            (if (equal? index len)
               (begin 
        	  (set! tmp (car(bengali_two_digit_number_to_words thisDigit)))
        	  (set! lokkho (string-append tmp " লক্ষ ") )
        	  (if (string-equal zero tmp)
        	      ()
        	      (set! out_string  (string-append lokkho out_string))
        	      (set! out_list (list out_list out_string))
	          )
               );end begin
             ;else
               (begin
                  (set! tens thisDigit)
               )
            )
         );index = 6
         ((equal? index 7)
            (set! thisDigit (car digit_list) )
            ;(print "index = 7")
            ;(print thisDigit)
            (set! digit_list (cdr digit_list))
            
            (set! tens (string-append thisDigit tens))
            ;(print tens)
            (set! tmp (car(bengali_two_digit_number_to_words tens)))
       	    (set! lokkho (string-append tmp " লক্ষ ") )
       	    (if (string-equal zero tmp)
        	()
        	(set! out_string  (string-append lokkho out_string))
        	(set! out_list (list out_list out_string))
	    )	    
         );index = 7
         ((equal? index 8)
            ;(print digit_list)
            ;(expand_bengali_integer_to_words_ digits)
            (set! out_string  (string-append " কোটি " out_string))
            (set! out_list (list out_list out_string))
            (set! out_string  (string-append (expand_bengali_integer_to_words_ digit_list) out_string))
            (set! out_list (list (expand_bengali_integer_to_words_ digit_list) out_list ))
         )
      );end of cond
      
      (set! index (+ index 1))
    );end of while
    ;(print "output")
    ;(print out_string)
    
    out_string
    ;out_list
  );;end of let
)
(define (expand_bengali_number_as_digit number)
 (let (digit_list len index out_string )
    (set! digit_list (symbolexplode number))
    (set! len (length digit_list))
    
    ;(print 'len)(print len)
    ;(print "list:")(print digit_list)
    ;(print (nth 0 digit_list) )
    ;(print 'cdr:)(print (cdr digit_list) )   
    (set! out_string "")
    
    (set! index 0)
    (while (< index len)
       (set! tmp (car(bengali_two_digit_number_to_words (nth index digit_list))))
       ;(print index)
       (set! index (+ index 1))
       (set! out_string  (string-append out_string tmp))
       (set! out_string  (string-append out_string " "))
    )
    (set! a out_string)
 );end of let
)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defvar ascii_char_hash (cons-array 256));
(defvar defined_ascii_char_hash)

(define (initialize_ascii_char_hash)
(let ((char 0))
      (while (<= char 255)
        (hset ascii_char_hash (string-append (format nil "%c" char)) char)
        (set! char (+ char 1)))
(set! defined_ascii_char_hash t)
))

(define (bengali_table_lookup abbr table)
  (cdr (assoc_string abbr table))
)

(define (ascii_of char)
(if (not defined_ascii_char_hash) (initialize_ascii_char_hash))
      (href ascii_char_hash char)
)

(defvar bengali_supplementary_char_list
  '("£" "€" "¥" "©" "®" "¢" "।" "॥"))

(defvar bengali_numbers_table
  '(
	("০" "0")
	("১" "1")
    	("২" "2")
    	("৩" "3")
    	("৪" "4")
    	("৫" "5")
    	("৬" "6")
    	("৭" "7")
    	("৮" "8")
    	("৯" "9")
))


(defvar english_basic_number_table
  '(
	("0" "জিরো ")
	("1" "ওয়ান ")
	("2" "টু ")
	("3" "থ্রি ")
	("4" "ফোর ")
	("5" "ফাইব ")
	("6" "সিক্স ")
	("7" "সেভেন ")
	("8" "এইট ")
	("9" "নাইন ")
))

(defvar english_basic_char_table
  '(
	("a" "এ ")
	("b" "বি ")
	("c" "সি ")
	("d" "ডি ")
	("e" "ই ")
	("f" "এফ ")
	("g" "জি ")
	("h" "এইচ ")
	("i" "আই ")
	("j" "জে ")
	("k" "কে ")
	("l" "এল ")
	("m" "এম ")
	("n" "এস ")
	("o" "ও ")
	("p" "পি ")
	("q" "কিউ ")
	("r" "আর ")
	("s" "এস ")
	("t" "টি ")
	("u" "ইউ ")
	("v" "ভি ")
	("w" "ডাবলিউ ")
	("x" "এক্স ")
	("y" "ওয়াই ")
	("z" "জেড ")
))

(defvar bengali_day_table
  '(
	("1লা" "পহেলা")
	("2রা" "দোশরা")
	("3রা" "তেশরা")
	("4ঠা" "চৌঠা")
	("5ই" "পাঁচই")
	("6ই" "ছয়ই")
	("7ই" "সাতই")
	("8ই" "আটই")
	("9ই" "নয়ই")
	("10ই" "দশই")
	("11ই" "এগারই")
	("12ই" "বারই")
	("13ই" "তেরই")
	("14ই" "চৌদ্দই")
	("15ই" "পনেরই")
	("16ই" "ষোলই")
	("17ই" "সতেরই")
	("18ই" "আঠারই")
	("19ই" "ঊনিশে")
	("20শে" "বিশে")
	("21শে" "একুশে")
	("22শে" "বাইশে")
	("23শে" "তেইশে")
	("24শে" "চব্বিশে")
	("25শে" "পঁচিশে")
	("26শে" "ছাব্বিশে")
	("27শে" "সাতাশে")
	("28শে" "আটাশে")
	("29শে" "ঊনত্রিশে")
	("30শে" "ত্রিশে")
	("31শে" "একত্রিশে")
	("1" "পহেলা")
	("2" "দোশরা")
	("3" "তেশরা")
	("4" "চৌঠা")
	("5" "পাঁচই")
	("6" "ছয়ই")
	("7" "সাতই")
	("8" "আটই")
	("9" "নয়ই")
	("10" "দশই")
	("11" "এগারই")
	("12" "বারই")
	("13" "তেরই")
	("14" "চৌদ্দই")
	("15" "পনেরই")
	("16" "ষোলই")
	("17" "সতেরই")
	("18" "আঠারই")
	("19" "ঊনিশে")
	("20" "বিশে")
	("21" "একুশে")
	("22" "বাইশে")
	("23" "তেইশে")
	("24" "চব্বিশে")
	("25" "পঁচিশে")
	("26" "ছাব্বিশে")
	("27" "সাতাশে")
	("28" "আটাশে")
	("29" "ঊনত্রিশে")
	("30" "ত্রিশে")
	("31" "একত্রিশে")
))


(defvar bengali_basic_number_table
  '(
	("0" "শূন্য")
	("1" "এক্")
	("2" "দুই")
	("3" "তিন্")
	("4" "চার্")
	("5" "পাঁচ্")
	("6" "ছয়্")
	("7" "সাত্")
	("8" "আট্")
	("9" "নয়্")
))

(defvar fail_safe
  '(
  	("।" "")  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	("৳" "টাকা")	
	("৲" "টাকা")
	("৴" "এক আনা")
	("৵" "দুই আনা")
	("৶" "তিন আনা")
	("৷" "চার আনা")
	("৸৹" "পাঁচ আনা")
	("!" "")
	("\"" "");"
	("#" "")
	("$" "ডলার")
	("%" "শতকরা")
	("&" "")
	("(" "")
	(")" "")
	("*" "")
	("+" "")
	("," "")
	("-" "")
	("." "")
	("/" "")
	(":" "")
	(";" "")
	("<" "")
	("=" "")
	(">" "")
	("?" "")
	("@" " এ্যাট ")
			;("[" "")
			;("\\\\" "শ্ল্যাস")
			;("]" "")
	("^" "")
	("_" "")
	("`" "")
))

(defvar bengali_two_digit_numbers_table
  '(
	("10" "দশ")
	("11" "এগারো")
	("12" "বারো")
	("13" "তেরো")
	("14" "চৌদ্দো")
	("15" "পনেরো")
	("16" "ষোলো")
	("17" "সতেরো")
	("18" "আঠারো")
	("19" "ঊনিশ")
	("20" "বিশ")
	("21" "একুশ")
	("22" "বাইশ")
	("23" "তেইশ")
	("24" "চব্বিশ")
	("25" "পঁচিশ")
	("26" "ছাব্বিশ")
	("27" "সাতাশ")
	("28" "আটাশ")
	("29" "ঊনত্রিশ")
	("30" "ত্রিশ")
	("31" "একত্রিশ")
	("32" "বত্রিশ")
	("33" "তেত্রিশ")
	("34" "চৌত্রিশ")
	("35" "পঁয়ত্রিশ")
	("36" "ছত্রিশ")
	("37" "সাতত্রিশ")
	("38" "আটত্রিশ")
	("39" "ঊনচল্লিশ")
	("40" "চল্লিশ")
	("41" "একচল্লিশ")
	("42" "বিয়াল্লিশ")
	("43" "তেতাল্লিশ")
	("44" "চুয়াল্লিশ")
	("45" "পঁয়তাল্লিশ")
	("46" "ছেচল্লিশ")
	("47" "সাতচল্লিশ")
	("48" "আটচল্লিশ")
	("49" "ঊনপঞ্চাশ")
	("50" "পঞ্চাশ")
	("51"  "একান্ন")
	("52" "বায়ান্ন")
	("53" "তেপান্ন")
	("54" "চুয়ান্ন")
	("55" "পঞ্চান্ন")
	("56" "ছাপ্পান্ন")
	("57" "সাতান্ন")
	("58" "আটান্ন")
	("59" "ঊনষাট")
	("60" "ষাট")
	("61" "একষট্টি")
	("62" "বাষট্টি")
	("63" "তেষট্টি")
	("64" "চৌষট্টি")
	("65" "পঁয়ষট্টি")
	("66" "ছেষট্টি")
	("67" "সাতষট্টি")
	("68" "আটষট্টি")
	("69" "ঊনসত্তর")
	("70" "সত্তর")
	("71" "একাত্তর")
	("72" "বাহাত্তর")
	("73" "তেয়াত্তর")
	("74" "চুয়াত্তর")
	("75" "পঁচাত্তর")
	("76" "ছিয়াত্তর")
	("77" "সাতাত্তর")
	("78" "আটাত্তর")
	("79" "ঊনআশি")
	("80" "আশি")
	("81" "একাশি")
	("82" "বিরাশি")
	("83" "তিরাশি")
	("84" "চুরাশি")
	("85" "পঁচাশি")
	("86"  "ছিয়াশি")
	("87" "সাতাশি")
	("88" "আটাশি")
	("89" "ঊননব্বই")
	("90" "নব্বই")
	("91" "একানব্বই")
	("92" "বিরানব্বই")
	("93" "তিরানব্বই")
	("94" "চুরানব্বই")
	("95" "পঁচানব্বই")
	("96"  "ছিয়ানব্বই")
	("97" "সাতানব্বই")
	("98" "আটানব্বই")
	("99" "নিরানব্বই")
))


(provide 'crblp_bnBD_alg_tokenizer)
